@@ -42,7 +42,7 @@ do
 done
 
 cp $TOPSRCDIR/doc/*.txt $BINDISTDIR/doc
-cp $TOPSRCDIR/README $BINDISTDIR/1README.txt
+cp $TOPSRCDIR/README.md $BINDISTDIR/1README.txt
 cp $TOPSRCDIR/COPYING $BINDISTDIR/1COPYING.txt
 
 unix2dos -q $BINDISTDIR/*.txt $BINDISTDIR/doc/*.txt
