@@ -566,7 +566,7 @@ static void audience_menu_treaty(struct audience_s *au)
     }
     all_num = 0;
     for (player_id_t i = PLAYER_0; i < g->players; ++i) {
-        if ((i != ph) && (i != pa) && ((ea->treaty[i] == TREATY_ALLIANCE) || (game_num_aud_ask_break_nap && (ea->treaty[i] == TREATY_NONAGGRESSION)))) {
+        if ((i != ph) && (i != pa) && BOOLVEC_IS1(ea->contact, i) && ((ea->treaty[i] == TREATY_ALLIANCE) || (game_num_aud_ask_break_nap && (ea->treaty[i] == TREATY_NONAGGRESSION)))) {
             all_tbl[all_num++] = i;
         }
     }
