@@ -257,18 +257,16 @@ void game_update_eco_on_waste(struct game_s *g, int player_i, bool force_adjust)
                 int16_t eco_diff = v - p->slider[PLANET_SLIDER_ECO];
                 int16_t sum = 100;
                 if (game_num_waste_adjust_fix) {
-                    sum = p->slider[PLANET_SLIDER_SHIP] + p->slider[PLANET_SLIDER_DEF] + p->slider[PLANET_SLIDER_IND];
+                    sum = p->slider[PLANET_SLIDER_SHIP] + p->slider[PLANET_SLIDER_DEF] + p->slider[PLANET_SLIDER_IND] + p->slider[PLANET_SLIDER_TECH];
                 }
                 if (check_locks) {
                     int16_t sum_locks = 0;
                     for (int si = 0; si < PLANET_SLIDER_NUM; ++si){
                         if (p->slider_lock[si]) {
                             sum_locks += p->slider[si];
-                            if (si != PLANET_SLIDER_TECH) {
-                                sum -= p->slider[si];
-                            }
                         }
                     }
+                    sum -= sum_locks;
                     SETMIN(v, 100 - sum_locks);
                 }
                 p->slider[PLANET_SLIDER_ECO] = v;
@@ -484,13 +482,13 @@ bool game_check_coord_is_visible(const struct game_s *g, player_id_t pi, int ran
     range = (range - 30) / 2;  /* 0, 10, 20, 30 */
     for (int i = 0; i < g->galaxy_stars; ++i) {
         const planet_t *p = &(g->planet[i]);
-        for (int j = 0; j < e->shipdesigns_num; ++j) {
-            if (e->orbit[i].ships[j]) {
-                if ((util_math_dist_fast(x, y, p->x, p->y) <= range)) {
-                    return true;
-                }
-                break;
-            }
+        uint32_t snum;
+        snum = 0;
+        for (int j = 0; (j < e->shipdesigns_num) && !snum; ++j) {
+            snum += e->orbit[i].ships[j];
+        }
+        if (snum && (util_math_dist_fast(x, y, p->x, p->y) <= range)) {
+            return true;
         }
     }
     for (int ei = 0; ei < g->enroute_num; ++ei) {
