@@ -8,6 +8,7 @@
 #include <string.h>
 #include <unistd.h>
 
+#include "game_nebula.h"
 #include "game_save.h"
 #include "bits.h"
 #include "game.h"
@@ -36,6 +37,44 @@ char game_save_tbl_name[NUM_ALL_SAVES][SAVE_NAME_LEN];
 
 /* -------------------------------------------------------------------------- */
 
+/*
+ * HACK: Nebula types are not stored in the save file format, but can be inferred
+ * from the bounding boxes.
+ */
+static bool game_save_nebula_match(uint16_t x, uint16_t y, const uint16_t *x0, const uint16_t *y0, const uint16_t *x1, const uint16_t *y1, const uint8_t nebula_data[4][4]) {
+    for (int i = 0; i < 4; ++i) {
+        if (x0[i] != x + nebula_data[0][i]) {
+            return false;
+        }
+        if (y0[i] != y + nebula_data[1][i]) {
+            return false;
+        }
+        if (x1[i] != x + nebula_data[2][i]) {
+            return false;
+        }
+        if (y1[i] != y + nebula_data[3][i]) {
+            return false;
+        }
+    }
+    return true;
+}
+
+static int game_save_infer_nebula_type(const struct game_s *g, uint32_t index)
+{
+    uint16_t x  = g->nebula_x[index];
+    uint16_t y  = g->nebula_y[index];
+    const uint16_t *x0 = g->nebula_x0[index];
+    const uint16_t *y0 = g->nebula_y0[index];
+    const uint16_t *x1 = g->nebula_x1[index];
+    const uint16_t *y1 = g->nebula_y1[index];
+    for (int t = 0; t < NEBULA_TYPE_NUM; ++t) {
+        if (game_save_nebula_match(x, y, x0, y0, x1, y1, tbl_nebula_data[t])) {
+            return t;
+        }
+    }
+    return -1;
+}
+
 static int game_save_encode_planet(uint8_t *buf, int pos, const planet_t *p, int pnum, uint32_t version)
 {
     SG_1OOM_EN_TBL_U8(p->name, PLANET_NAME_LEN);
@@ -86,9 +125,7 @@ static int game_save_encode_planet(uint8_t *buf, int pos, const planet_t *p, int
     SG_1OOM_EN_U8(p->unrest);
     SG_1OOM_EN_U8(p->unrest_reported);
     SG_1OOM_EN_BV(p->finished, FINISHED_NUM);
-    SG_1OOM_EN_BV(p->extras, PLANET_EXTRAS_NUM);
-    SG_1OOM_EN_U16(p->target_bases);
-    SG_1OOM_EN_DUMMY(2);
+    SG_1OOM_EN_DUMMY(5);
     return pos;
 }
 
@@ -142,9 +179,7 @@ static int game_save_decode_planet(const uint8_t *buf, int pos, planet_t *p, int
     SG_1OOM_DE_U8(p->unrest);
     SG_1OOM_DE_U8(p->unrest_reported);
     SG_1OOM_DE_BV(p->finished, FINISHED_NUM);
-    SG_1OOM_DE_BV(p->extras, PLANET_EXTRAS_NUM);
-    SG_1OOM_DE_U16(p->target_bases);
-    SG_1OOM_DE_DUMMY(2);
+    SG_1OOM_DE_DUMMY(5);
     return pos;
 }
 
@@ -565,16 +600,7 @@ static int game_save_encode_evn(uint8_t *buf, int pos, const gameevents_t *ev, i
     SG_1OOM_EN_TBL_TBL_U16(ev->ceasefire, pnum, pnum);
     for (int i = 0; i < pnum; ++i) {
         SG_1OOM_EN_BV(ev->help_shown[i], HELP_SHOWN_NUM);
-        SG_1OOM_EN_BV(ev->msg_filter[i], FINISHED_NUM);
-        {
-            uint8_t v;
-            v = ev->gov_eco_mode[i];
-            if (BOOLVEC_IS1(ev->gov_no_stargates, i)) {
-                v |= 0x80;
-            }
-            SG_1OOM_EN_U8(v);
-        }
-        SG_1OOM_EN_DUMMY(12);
+        SG_1OOM_EN_DUMMY(14);
     }
     SG_1OOM_EN_TBL_U16(ev->build_finished_num, pnum);
     SG_1OOM_EN_TBL_U8(ev->voted, pnum);
@@ -622,14 +648,7 @@ static int game_save_decode_evn(const uint8_t *buf, int pos, gameevents_t *ev, i
     SG_1OOM_DE_TBL_TBL_U16(ev->ceasefire, pnum, pnum);
     for (int i = 0; i < pnum; ++i) {
         SG_1OOM_DE_BV(ev->help_shown[i], HELP_SHOWN_NUM);
-        SG_1OOM_DE_BV(ev->msg_filter[i], FINISHED_NUM);
-        {
-            uint8_t v;
-            SG_1OOM_DE_U8(v);
-            ev->gov_eco_mode[i] = v & 7;
-            BOOLVEC_SET(ev->gov_no_stargates, i, (v & 0x80) != 0);
-        }
-        SG_1OOM_DE_DUMMY(12);
+        SG_1OOM_DE_DUMMY(14);
     }
     SG_1OOM_DE_TBL_U16(ev->build_finished_num, pnum);
     SG_1OOM_DE_TBL_U8(ev->voted, pnum);
@@ -733,6 +752,10 @@ static int game_save_decode(const uint8_t *buf, int buflen, struct game_s *g, ui
     SG_1OOM_DE_DUMMY(3);
     SG_1OOM_DE_U8(g->active_player);
     SG_1OOM_DE_U8(g->difficulty);
+    if ((g->difficulty < 0) || (g->difficulty >= DIFFICULTY_NUM)) {
+        log_error("Save: decode invalid difficulty value %i\n", g->difficulty);
+        return -1;
+    }
     SG_1OOM_DE_U8(g->galaxy_size);
     SG_1OOM_DE_U8(g->galaxy_w);
     SG_1OOM_DE_U8(g->galaxy_h);
@@ -770,6 +793,14 @@ static int game_save_decode(const uint8_t *buf, int buflen, struct game_s *g, ui
     SG_1OOM_DE_TBL_TBL_U16(g->nebula_x1, g->nebula_num, 4);
     SG_1OOM_DE_TBL_TBL_U16(g->nebula_y0, g->nebula_num, 4);
     SG_1OOM_DE_TBL_TBL_U16(g->nebula_y1, g->nebula_num, 4);
+    for (int i = 0; i < g->nebula_num; ++i) {
+        g->nebula_type[i] = game_save_infer_nebula_type(g, i);
+        if (g->nebula_type[i] < 0) {
+            log_error("Save: unknown nebula type for nebula %i\n", i);
+            return -1;
+        }
+    }
+
     SG_1OOM_DE_TBL_TBL_U8(g->emperor_names, g->players, EMPEROR_NAME_LEN);
     SG_1OOM_DE_TBL_U8(g->planet_focus_i, g->players);
     for (int i = 0; i < g->galaxy_stars; ++i) {
@@ -826,13 +857,6 @@ static int game_save_decode(const uint8_t *buf, int buflen, struct game_s *g, ui
             }
         }
     }
-    /* generate message filter if needed */
-    for (player_id_t i = PLAYER_0; i < g->players; ++i) {
-        if (IS_HUMAN(g, i) && BOOLVEC_IS_CLEAR(g->evn.msg_filter[i], FINISHED_NUM)) { /* the SHIP bit is always 1 */
-            g->evn.msg_filter[i][0] = FINISHED_DEFAULT_FILTER;
-        }
-    }
-
     g->guardian_killer = PLAYER_NONE;
     return 0;
 }
@@ -969,8 +993,8 @@ int game_save_get_slot_fname(char *buf, int buflen, int i)
     const char *path = os_get_path_user();
     char namebuf[16];
     int res;
-    if (!os_get_fname_save_slot(namebuf, i + 1)) {
-        sprintf(namebuf, "1oom_save%i.bin", i + 1);
+    if (!os_get_fname_save_slot(namebuf, sizeof(namebuf), i + 1)) {
+        lib_sprintf(namebuf, sizeof(namebuf), "1oom_save%i.bin", i + 1);
     }
     res = util_concat_buf(buf, buflen, path, FSDEV_DIR_SEP_STR, namebuf, NULL);
     if (res < 0) {
@@ -985,8 +1009,8 @@ int game_save_get_year_fname(char *buf, int buflen, int year)
     const char *path = os_get_path_user();
     char namebuf[32];
     int res;
-    if (!os_get_fname_save_year(namebuf, year)) {
-        sprintf(namebuf, "1oom_save_%i.bin", year);
+    if (!os_get_fname_save_year(namebuf, sizeof(namebuf), year)) {
+        lib_sprintf(namebuf, sizeof(namebuf), "1oom_save_%i.bin", year);
     }
     res = util_concat_buf(buf, buflen, path, FSDEV_DIR_SEP_STR, namebuf, NULL);
     if (res < 0) {
@@ -1064,7 +1088,7 @@ int game_save_do_save_year(const char *savename, const struct game_s *g)
     }
     game_save_get_year_fname(filename, g->gaux->savenamebuflen, g->year + YEAR_BASE);
     if (!savename) {
-        sprintf(buf, "Year %i", g->year + YEAR_BASE);
+        lib_sprintf(buf, sizeof(buf), "Year %i", g->year + YEAR_BASE);
         savename = buf;
     }
     res = game_save_do_save_do(filename, savename, g, -1, GAME_SAVE_VERSION);
