@@ -17,50 +17,64 @@
 
 /* -------------------------------------------------------------------------- */
 
-static uint8_t game_spy_esp_sub3_sub1(struct game_s *g, uint8_t a0, tech_field_t field, uint16_t slen, const uint8_t *src)
+static uint8_t game_spy_esp_get_group_tier(struct game_s *g, tech_group_t group, tech_field_t field, uint16_t len, const uint8_t *research_completed)
 {
     int v = 0;
-    for (int i = 0; i < slen; ++i) {
+    for (int i = 0; i < len; ++i) {
         uint8_t techi;
-        const uint8_t *p;
-        techi = src[i];
-        p = RESEARCH_D0_PTR(g->gaux, field, techi);
-        if (a0 == p[0]) {
-            v = RESEARCH_D0_B1(p);
+        tech_group_t group2;
+        techi = research_completed[i];
+        group2 = game_tech_get_group(g->gaux, field, techi);
+        if (group == group2) {
+            v = game_tech_get_tier(g->gaux, field, techi);
         }
     }
     return v;
 }
 
-static void game_spy_esp_sub3(struct game_s *g, struct spy_esp_s *s, tech_field_t field, int tlen, const uint8_t *trc, int slen, const uint8_t *src)
+static void game_spy_esp_sift_useful_techs_do(struct game_s *g, struct spy_esp_s *s, tech_field_t field, int target_len, const uint8_t *target_research_completed, int spy_len, const uint8_t *spy_research_completed)
 {
-    for (int i = 0; i < tlen; ++i) {
-        const uint8_t *p;
-        uint8_t techi, b0, b1;
+    for (int i = 0; i < target_len; ++i) {
+        uint8_t techi, tier;
+        tech_group_t group;
         bool have_tech;
-        techi = trc[i];
-        p = RESEARCH_D0_PTR(g->gaux, field, techi);
-        b0 = p[0];
-        b1 = RESEARCH_D0_B1(p);
+        techi = target_research_completed[i];
+        group = game_tech_get_group(g->gaux, field, techi);
+        tier = game_tech_get_tier(g->gaux, field, techi);
         have_tech = false;
-        for (int j = 0; j < slen; ++j) {
-            if (src[j] == techi) {
+        for (int j = 0; j < spy_len; ++j) {
+            if (spy_research_completed[j] == techi) {
                 have_tech = true;
                 break;
             }
         }
         if (0
-          || ((b0 >= 3) && (b0 <= 6))
-          || (b0 == 10) || (b0 == 18) || (b0 == 21)
-          || ((b0 >= 12) && (b0 <= 16))
+          || (group == TECH_GROUP_IMPROVED_ROBOTIC_CONTROLS)
+          || (group == TECH_GROUP_SPACE_SCANNER)
+          || (group == TECH_GROUP_REDUCED_INDUSTRIAL_WASTE)
+          || (group == TECH_GROUP_IMPROVED_INDUSTRIAL_TECH)
+          || (group == TECH_GROUP_PLANETARY_SHIELD)
+          || (group == TECH_GROUP_IMPROVED_TERRAFORMING)
+          || (group == TECH_GROUP_CONTROLLED_ENVIRONMENT)
+          || (group == TECH_GROUP_ECO_RESTORATION)
+          || (group == TECH_GROUP_PERSONAL_ARMOR)
+          || (group == TECH_GROUP_PERSONAL_SHIELD)
+          || (group == TECH_GROUP_FUEL_CELLS)
+          || (group == TECH_GROUP_PERSONAL_WEAPONS)
         ) {
-            if (game_spy_esp_sub3_sub1(g, b0, field, slen, src) >= b1) {
+            if (game_spy_esp_get_group_tier(g, group, field, spy_len, spy_research_completed) >= tier) {
                 have_tech = true;
             }
         }
         /*632ff*/
-        if ((g->eto[s->spy].race == RACE_SILICOID) && ((b0 == 5) || (b0 == 13) || (b0 == 14))) {
-            have_tech = true;
+        if (g->eto[s->spy].race == RACE_SILICOID) {
+            if (0
+              || (group == TECH_GROUP_REDUCED_INDUSTRIAL_WASTE)
+              || (group == TECH_GROUP_CONTROLLED_ENVIRONMENT)
+              || (group == TECH_GROUP_ECO_RESTORATION)
+            ) {
+                have_tech = true;
+            }
         }
         if (!have_tech) {
             s->tbl_techi[field][s->tbl_num[field]++] = techi;
@@ -68,22 +82,24 @@ static void game_spy_esp_sub3(struct game_s *g, struct spy_esp_s *s, tech_field_
     }
 }
 
-static int game_spy_esp_get_value(struct game_s *g, struct spy_esp_s *s, tech_field_t field, uint8_t techi)
+static int game_spy_esp_get_value(struct game_s *g, tech_field_t field, uint8_t techi, player_id_t player_i)
 {
-    empiretechorbit_t *es = &(g->eto[s->spy]);
-    const shipresearch_t *srds = &(g->srd[s->spy]);
-    uint8_t b0 = RESEARCH_D0_PTR(g->gaux, field, techi)[0], maxb1 = 0, maxti = 0;
+    const empiretechorbit_t *es = &(g->eto[player_i]);
+    const shipresearch_t *srds = &(g->srd[player_i]);
+    uint8_t maxtier = 0, maxti = 0;
+    tech_group_t group = game_tech_get_group(g->gaux, field, techi);
     int v;
-    if (b0 & 0x80) {
+    if (group & 0x80) {
         return 0;
     }
     for (int i = 0; i < es->tech.completed[field]; ++i) {
-        const uint8_t *p;
-        uint8_t ti;
+        uint8_t tier2, ti;
+        tech_group_t group2;
         ti = srds->researchcompleted[field][i];
-        p = RESEARCH_D0_PTR(g->gaux, field, ti);
-        if ((p[0] == b0) && (p[1] > maxb1)) {
-             maxb1 = p[1];
+        group2 = game_tech_get_group(g->gaux, field, ti);
+        tier2 = game_tech_get_tier(g->gaux, field, ti);
+        if ((group2 == group) && (tier2 > maxtier)) {
+             maxtier = tier2;
              maxti = ti;
         }
     }
@@ -127,16 +143,16 @@ static int game_spy_esp_get_value(struct game_s *g, struct spy_esp_s *s, tech_fi
 #endif
     /*62f24*/
     v = techi * techi;
-    if (b0 == 0) {
+    if (group == TECH_GROUP_SINGULAR) {
         v *= 10;
     }
-    if (b0 == 3) {
+    if (group == TECH_GROUP_IMPROVED_ROBOTIC_CONTROLS) {
         v *= 6;
     }
-    if (b0 == 5) {
+    if (group == TECH_GROUP_REDUCED_INDUSTRIAL_WASTE) {
         v *= 3;
     }
-    if (b0 == 14) {
+    if (group == TECH_GROUP_ECO_RESTORATION) {
         v *= 3;
     }
     if (maxti > techi) {
@@ -145,8 +161,14 @@ static int game_spy_esp_get_value(struct game_s *g, struct spy_esp_s *s, tech_fi
     if (maxti == techi) {
         v = 0;
     }
-    if ((es->race == RACE_SILICOID) && ((b0 == 5) || (b0 == 13) || (b0 == 14))) {
-        v = 0;
+    if (es->race == RACE_SILICOID) {
+        if (0
+          || (group == TECH_GROUP_REDUCED_INDUSTRIAL_WASTE)
+          || (group == TECH_GROUP_CONTROLLED_ENVIRONMENT)
+          || (group == TECH_GROUP_ECO_RESTORATION)
+        ) {
+            v = 0;
+        }
     }
     if ((field == TECH_FIELD_WEAPON) && (techi == TECH_WEAP_DEATH_RAY)) {
         v = 30000;
@@ -348,7 +370,7 @@ int game_spy_esp_sub1(struct game_s *g, struct spy_esp_s *s, int a4, int a6)
                     have_tech = true;
                 }
             }
-            value = game_spy_esp_get_value(g, s, field, techi);
+            value = game_spy_esp_get_value(g, field, techi, s->spy);
             if ((value == 0) || (value < a4)) {
                 have_tech = true;
             }
@@ -376,7 +398,7 @@ int game_spy_esp_sub2(struct game_s *g, struct spy_esp_s *s, int a4)
         s->tbl_num[f] = 0;
     }
     for (tech_field_t f = 0; f < TECH_FIELD_NUM; ++f) {
-        game_spy_esp_sub3(g, s, f, et->tech.completed[f] - a4, srdt->researchcompleted[f], es->tech.completed[f], srds->researchcompleted[f]);
+        game_spy_esp_sift_useful_techs_do(g, s, f, et->tech.completed[f] - a4, srdt->researchcompleted[f], es->tech.completed[f], srds->researchcompleted[f]);
     }
     for (tech_field_t f = 0; f < TECH_FIELD_NUM; ++f) {
         sum += s->tbl_num[f];
@@ -584,7 +606,7 @@ void game_spy_esp_human(struct game_s *g, struct spy_turn_s *st)
                         g->evn.stolen_tech[target][spy] = tbl_tech[field];
                         game_tech_get_new(g, spy, field, tbl_tech[field], TECHSOURCE_SPY, planet, target, framed);
                         if (!framed) {
-                            game_diplo_act(g, -g->evn.spied_spy[target][spy], spy, target, 4, 0, target);
+                            game_diplo_act(g, -g->evn.spied_spy[target][spy], spy, target, 4, 0, field);
                         }
                         game_tech_finish_new(g, spy);
                         ui_newtech(g, spy);
