@@ -211,7 +211,7 @@ const char *game_str_sm_unexplored = "UNEXPLORED";
 const char *game_str_sm_nohabit = "NO HABITABLE";
 const char *game_str_sm__planets = "PLANETS";
 
-const char *game_str_tbl_sm_pltype[PLANET_TYPE_NUM] = {
+const char *game_str_tbl_sm_pltype[PLANET_TYPE_NUM + 1] = {
     "NO HABITABLE PLANETS", "RADIATED", "TOXIC", "INFERNO", "DEAD",
     "TUNDRA", "BARREN", "MINIMAL", "DESERT", "STEPPE", "ARID", "OCEAN",
     "JUNGLE", "TERRAN", "GAIA"
@@ -325,9 +325,12 @@ const char *game_str_tbl_roman[31] = {
 };
 
 const char *game_str_no_events = "No Events";
+const char *game_str_no_elections = "No Elections";
 const char *game_str_bc = "BC";
 const char *game_str_y = "Y";
-const char *game_str_year = "Year:";
+const char *game_str_year = "Year ";
+const char *game_str_year0 = "/Year";
+const char *game_str_year1 = "Year:";
 const char *game_str_player = "Player";
 
 const char *game_str_pl_reserve = "Reserve";
@@ -434,7 +437,6 @@ const char *game_str_gm_mapkey = "Map Key";
 
 const char *game_str_bs_line1 = "How many missile";
 const char *game_str_bs_line2 = "bases to eliminate?";
-const char *game_str_bs_base = "Base";
 const char *game_str_bs_bases = "Bases";
 
 const char *game_str_tbl_te_field[TECH_FIELD_NUM] = {
@@ -488,7 +490,12 @@ const char *game_str_adj_max = " ratios of all of your colonies to maximum?";
 const char *game_str_adj_slider[PLANET_SLIDER_NUM] = {
     "ship", "defense", "industry", "ecology", "technology"
 };
+const char *game_str_adj_colonies = " colonies?";
 const char *game_str_adj_lock = " slider lock for all of your colonies?";
+const char *game_str_adj_lock2 = " slider lock for ";
+const char *game_str_adj_special[7] = {
+    "ultra poor", "poor", "normal", "artifacts", "rich", "ultra rich", "4x tech"
+};
 
 const char *game_str_ra_nocont = "No Contact";
 const char *game_str_ra_notpres = "Not Present";
