@@ -64,10 +64,8 @@ static void game_turn_countdown_ceasefire(struct game_s *g)
 {
     for (player_id_t j = PLAYER_0; j < g->players; ++j) {
         for (player_id_t i = PLAYER_0; i < g->players; ++i) {
-            uint8_t v;
-            v = g->evn.ceasefire[j][i];
-            if (v > 0) {
-                g->evn.ceasefire[j][i] = v - 1;
+            if (g->evn.ceasefire[j][i] > 0) {
+                --g->evn.ceasefire[j][i];
             }
         }
     }
@@ -169,6 +167,27 @@ static void game_turn_send_transport(struct game_s *g)
     }
 }
 
+static int game_turn_build_eco_sub1(int fact, int colonist_oper_fact, int pop1, int waste, int max_pop2)
+{
+    if (game_num_waste_calc_fix) {
+        /* WASBUG
+           MOO1 adds waste twice using two separate pieces of code.
+           The first time (see above) is as described in OSG.
+           The second time (see below, from game_turn_build_eco_sub1) has several issues:
+           - p->pop * e->colonist_oper_factories * e->colonist_oper_factories / 10 makes no sense
+           - since p->waste is not limited at this point, the value added can be negative, leading to Silicoid planets with 0 waste
+           - the cost of eco restoration is already calculated; as the slider is typically set to Clean (ecorestore <= ecoprod) the point is mostly moot
+           Speculation: Someone added the above working code and forgot to remove this broken code.
+        */
+        return 0;
+    }
+    int v;
+    v = pop1 * colonist_oper_fact;
+    SETMIN(fact, v);
+    v = (fact * colonist_oper_fact) / 10;
+    return ((100 - ((waste * 100) / max_pop2)) * v) / 100;
+}
+
 static inline void game_add_planet_to_eco_finished(struct game_s *g, uint8_t pli, player_id_t owner)
 {
     BOOLVEC_SET1(g->planet[pli].finished, FINISHED_SOILATMOS);
@@ -183,35 +202,21 @@ static void game_turn_build_eco(struct game_s *g)
         p->pop_prev = (owner != PLAYER_NONE) ? p->pop : 0;
         if ((owner != PLAYER_NONE) && (p->type != PLANET_TYPE_NOT_HABITABLE) && (p->pop != 0)) {
             const empiretechorbit_t *e;
-            int ecorestore, ecoprod, operating_factories;
+            int ecorestore, ecoprod;
             e = &(g->eto[owner]);
-            operating_factories = p->pop * game_planet_get_pop_oper_fact(g, p);
-            SETMIN(operating_factories, p->factories);
             {
-                int v;
-                v = (operating_factories * e->ind_waste_scale) / 10;
-                v = ((100 - ((p->waste * 100) / p->max_pop2)) * v) / 100;
-                p->waste += v;
+                int v, fact, waste;
+                fact = p->factories;
+                v = p->pop * game_planet_get_pop_oper_fact(g, p);
+                SETMIN(fact, v);
+                waste = (fact * e->ind_waste_scale) / 10;
+                p->waste += ((100 - ((p->waste * 100) / p->max_pop2)) * waste) / 100;
             }
             if (p->unrest == PLANET_UNREST_REBELLION) {
                 p->waste = 0;
             }
             ecorestore = (e->race != RACE_SILICOID) ? (p->waste / e->have_eco_restoration_n) : 0;
-            if (!game_num_waste_calc_fix) {
-                /* WASBUG
-                   MOO1 adds waste twice using two separate pieces of code.
-                   The first time (see above) is as described in OSG.
-                   The second time (see below, from game_turn_build_eco_sub1) has several issues:
-                   - p->pop * e->colonist_oper_factories * e->colonist_oper_factories / 10 makes no sense
-                   - since p->waste is not limited at this point, the value added can be negative, leading to Silicoid planets with 0 waste
-                   - the cost of eco restoration is already calculated; as the slider is typically set to Clean (ecorestore <= ecoprod) the point is mostly moot
-                   Speculation: Someone added the above working code and forgot to remove this broken code.
-                */
-                int v;
-                v = (operating_factories * e->colonist_oper_factories) / 10; /* WASBUG this makes no sense */
-                v = ((100 - ((p->waste * 100) / p->max_pop2)) * v) / 100; /* WASBUG p->waste can be > p->max_pop2 here */
-                p->waste += v;
-            }
+            p->waste += game_turn_build_eco_sub1(p->factories, game_planet_get_pop_oper_fact(g, p), p->pop, p->waste, p->max_pop2);
             ecoprod = (p->slider[PLANET_SLIDER_ECO] * p->prod_after_maint) / 100;
             if (e->race != RACE_SILICOID) {
                 if (ecorestore > ecoprod) {
@@ -501,7 +506,7 @@ static void game_turn_build_def(struct game_s *g)
                 int curcost;
                 curcost = MIN(e->planet_shield_cost, p->bc_to_shield);
                 newshield = 0;
-                for (int i = 1; (i < PSHIELD_NUM) && (curcost >= game_num_pshield_cost[i]); ++i) {
+                for (int j = 1; (j < PSHIELD_NUM) && (curcost >= game_num_pshield_cost[j]); ++j) {
                     newshield += 5;
                 }
                 if (newshield != p->shield) {
@@ -576,17 +581,19 @@ static void game_turn_build_ship(struct game_s *g)
                     shipnum = game_num_limit_ships_all - srd->shipcount[si];
                 }
                 SETMAX(shipnum, 0);
-                if (shipnum > 0) {
-                    srd->shipcount[si] += shipnum;
-                    dest = p->reloc;
-                    if (dest == i) {
-                        e->orbit[i].ships[si] += shipnum;
+                srd->shipcount[si] += shipnum;
+                dest = p->reloc;
+                if (dest == i) {
+                    e->orbit[i].ships[si] += shipnum;
+                    if (shipnum > 0) {
                         BOOLVEC_SET1(p->finished, FINISHED_SHIP);
-                    } else {
+                    }
+                } else {
+                    if (shipnum > 0) {
                         game_send_fleet_reloc(g, owner, i, dest, si, shipnum);
                     }
-                    g->evn.new_ships[owner][si] += shipnum;
                 }
+                g->evn.new_ships[owner][si] += shipnum;
                 p->bc_to_ship = prod;
             }
         }
@@ -628,6 +635,38 @@ static inline void game_add_planet_to_build_finished(struct game_s *g, uint8_t p
     ++g->evn.build_finished_num[owner];
 }
 
+static bool game_turn_finished_switch_slider(struct game_s *g, struct planet_s *p, planet_slider_i_t from, planet_slider_i_t to)
+{
+    if (game_num_slider_respects_locks && (p->slider_lock[from] || p->slider_lock[to])) {
+        return false;
+    }
+    if (from == to) {
+        return false;
+    }
+    int v = p->slider[from];
+    if (from == PLANET_SLIDER_ECO) {
+        v -= game_planet_get_waste_percent(NULL, g, p, false);
+        SETMAX(v, 0);
+    }
+    p->slider[from] -= v;
+    p->slider[to] += v;
+    return true;
+}
+
+static void game_turn_finished_disable_slider(struct game_s *g, struct planet_s *p, planet_slider_i_t from, bool build_ind)
+{
+    if (game_num_slider_respects_locks && p->slider_lock[from]) {
+        return;
+    }
+    planet_slider_i_t first = build_ind ? PLANET_SLIDER_IND : PLANET_SLIDER_TECH;
+    game_turn_finished_switch_slider(g, p, from, first)
+    || game_turn_finished_switch_slider(g, p, from, PLANET_SLIDER_TECH)
+    || game_turn_finished_switch_slider(g, p, from, PLANET_SLIDER_SHIP)
+    || game_turn_finished_switch_slider(g, p, from, PLANET_SLIDER_DEF)
+    || game_turn_finished_switch_slider(g, p, from, PLANET_SLIDER_IND)
+    || game_turn_finished_switch_slider(g, p, from, PLANET_SLIDER_ECO);
+}
+
 static void game_turn_build_ind(struct game_s *g)
 {
     for (int i = 0; i < g->galaxy_stars; ++i) {
@@ -699,8 +738,7 @@ static void game_turn_build_ind(struct game_s *g)
             p->factories = fact;
             if ((fact != factold) && (fact >= (p->max_pop3 * e->colonist_oper_factories))) {
                 if (IS_HUMAN(g, owner) && (p->slider[PLANET_SLIDER_IND] > 0)) {
-                    p->slider[PLANET_SLIDER_TECH] += p->slider[PLANET_SLIDER_IND];
-                    p->slider[PLANET_SLIDER_IND] = 0;
+                    game_turn_finished_disable_slider(g, p, PLANET_SLIDER_IND, false);
                 }
                 game_add_planet_to_build_finished(g, i, owner, FINISHED_FACT);
             }
@@ -840,6 +878,35 @@ static void game_turn_move_ships(struct game_s *g)
     game_update_visibility(g);
 }
 
+#if 0
+static void game_turn_unrest_hmm1(struct game_s *g)
+{
+    /* this does nothing except churn the rng! */
+    int tbl1[PLAYER_NUM], tbl2[PLAYER_NUM];
+    for (player_id_t i = PLAYER_0; i < g->players; ++i) {
+        tbl1[i] = 0;
+        tbl2[i] = 0;
+    }
+    for (player_id_t i = PLAYER_0; i < g->players; ++i) {
+        const planet_t *p;
+        int pl, v;
+        v = tbl2[i] * 2;   /* always 0 */
+        pl = game_planet_get_random(g, i);
+        if (pl != PLANET_NONE) {
+            p = &(g->planet[pi]);
+            /* WASBUG unrest != RESOLVED test done even when pl < 0 */
+            if ((p->unrest != PLANET_UNREST_REBELLION) || (p->unrest != PLANET_UNREST_RESOLVED)) {
+                if (rnd_1_n(100, &g->seed) <= v) {  /* never true */
+                    p->unrest = PLANET_UNREST_REBELLION;
+                    p->unrest_reported = false;
+                    p->rebels = p->pop / 2;
+                }
+            }
+        }
+    }
+}
+#endif
+
 static void game_turn_explore(struct game_s *g)
 {
     for (int pli = 0; pli < g->galaxy_stars; ++pli) {
@@ -1112,9 +1179,9 @@ static void game_turn_transport(struct game_s *g)
             if (g->evn.have_guardian && (dest == g->evn.planet_orion_i)) {
                 pop3 = 0;
             }
-            for (monster_id_t i = MONSTER_CRYSTAL; i <= MONSTER_AMOEBA; ++i) {
+            for (monster_id_t j = MONSTER_CRYSTAL; j <= MONSTER_AMOEBA; ++j) {
                 monster_t *m;
-                m = (i == MONSTER_CRYSTAL) ? &(g->evn.crystal) : &(g->evn.amoeba);
+                m = (j == MONSTER_CRYSTAL) ? &(g->evn.crystal) : &(g->evn.amoeba);
                 if (m->exists && /*(m->killer == PLAYER_NONE) &&*/ (m->x == p->x) && (m->y == p->y)) { /* FIXME dead monster kills transports ? */
                     pop3 = 0;
                 }
@@ -1163,15 +1230,21 @@ static void game_turn_transport(struct game_s *g)
                 }
             } else {
                 /*e3fe*/
-#if 0
-                if ((p->owner == PLAYER_NONE) || (p->pop == 0)) { /* never true (tested above) */
-                    /* ignored */
-                } else
-#endif
-                if (p->owner == owner) {
+                if ((p->owner == PLAYER_NONE) || (p->pop == 0)) {
+                    if (IS_HUMAN(g, owner)) {
+                        ui_landing(g, owner, dest);
+                    }
+                    p->pop = pop3;
+                    p->bc_to_refit = 0;
+                    p->pop_oper_fact = 1;
+                    if (dest == g->evn.planet_orion_i) {
+                        g->evn.have_orion_conquer = owner + 1;
+                    }
+                    p->owner = owner;
+                } else if (p->owner == owner) {
                     if (p->unrest == PLANET_UNREST_REBELLION) {
                         ADDSATT(p->inbound[owner], pop3, game_num_max_inbound);
-                        p->total_inbound[owner] += pop2;
+                        p->total_inbound[owner] += pop3;
                     } else {
                         ADDSATT(p->pop, pop3, p->max_pop3);
                     }
@@ -1208,7 +1281,7 @@ static void game_turn_coup(struct game_s *g)
         }
     }
     for (player_id_t i = PLAYER_0; i < g->players; ++i) {
-        if ((tbl_rebelplanets[i] > tbl_planets[i] / 2) && IS_ALIVE(g, i)) {
+        if ((tbl_rebelplanets[i] >= (tbl_planets[i] + 1) / 2) && IS_ALIVE(g, i)) {
             empiretechorbit_t *e = &(g->eto[i]);
             e->trait2 = rnd_0_nm1(TRAIT2_NUM, &g->seed);
             e->trait1 = rnd_0_nm1(TRAIT1_NUM, &g->seed);
@@ -1326,7 +1399,7 @@ static void game_turn_update_have_met(struct game_s *g)
     game_update_empire_contact(g);
     for (player_id_t i = PLAYER_0; i < g->players; ++i) {
         empiretechorbit_t *e = &(g->eto[i]);
-        if (IS_AI(g, i)) {
+        if (!IS_HUMAN(g, i)) {
             continue;
         }
         for (player_id_t j = PLAYER_0; j < g->players; ++j) {
@@ -1432,14 +1505,7 @@ static void game_turn_finished_slider(struct game_s *g)
         }
         if (BOOLVEC_IS1(p->finished, FINISHED_SOILATMOS)
           && !(game_num_slider_eco_done_fix && game_planet_can_terraform(g, p, p->owner, true))) {
-            int v;
-            v = game_planet_get_waste_percent(NULL, g, p, false);
-            if (!cond_build_ind) {
-                p->slider[PLANET_SLIDER_TECH] += p->slider[PLANET_SLIDER_ECO] - v;
-            } else {
-                p->slider[PLANET_SLIDER_IND] += p->slider[PLANET_SLIDER_ECO] - v;
-            }
-            p->slider[PLANET_SLIDER_ECO] = v;
+            game_turn_finished_disable_slider(g, p, PLANET_SLIDER_ECO, cond_build_ind);
             game_add_planet_to_build_finished(g, pli, pi, FINISHED_SOILATMOS);
         }
         if (1
@@ -1469,12 +1535,7 @@ static void game_turn_finished_slider(struct game_s *g)
                   || ((p->slider[PLANET_SLIDER_ECO] != 0) && (e->race == RACE_SILICOID))
                 ) {
                     if ((p->pop > p->pop_prev) || (p->slider[PLANET_SLIDER_ECO] > (w + game_num_eco_slider_slack))) {
-                        if (!cond_build_ind) {
-                            p->slider[PLANET_SLIDER_TECH] += p->slider[PLANET_SLIDER_ECO] - w;
-                        } else {
-                            p->slider[PLANET_SLIDER_IND] += p->slider[PLANET_SLIDER_ECO] - w;
-                        }
-                        p->slider[PLANET_SLIDER_ECO] = w;
+                        game_turn_finished_disable_slider(g, p, PLANET_SLIDER_ECO, cond_build_ind);
                         if (p->pop > p->pop_prev) {
                             game_add_planet_to_build_finished(g, pli, pi, FINISHED_POPMAX);
                         }
@@ -1484,24 +1545,19 @@ static void game_turn_finished_slider(struct game_s *g)
                   && (p->slider[PLANET_SLIDER_ECO] > 0)
                   && ((e->race == RACE_SILICOID) || ((e->ind_waste_scale == 0) && (p->waste == 0)))
                 ) {
-                    if (!cond_build_ind) {
-                        p->slider[PLANET_SLIDER_TECH] += p->slider[PLANET_SLIDER_ECO];
-                    } else {
-                        p->slider[PLANET_SLIDER_IND] += p->slider[PLANET_SLIDER_ECO];
-                    }
-                    p->slider[PLANET_SLIDER_ECO] = 0;
+                    game_turn_finished_disable_slider(g, p, PLANET_SLIDER_ECO, cond_build_ind);
                 }
             }
         }
         if (BOOLVEC_IS1(p->finished, FINISHED_SHIELD)) {
-            p->slider[PLANET_SLIDER_TECH] += p->slider[PLANET_SLIDER_DEF];
-            p->slider[PLANET_SLIDER_DEF] = 0;
+            game_turn_finished_disable_slider(g, p, PLANET_SLIDER_DEF, false);
             game_add_planet_to_build_finished(g, pli, pi, FINISHED_SHIELD);
         }
         if (BOOLVEC_IS1(p->finished, FINISHED_STARGATE)) {
             /* WASBUG MOO1 has DEF, not SHIP */
-            p->slider[PLANET_SLIDER_TECH] += p->slider[PLANET_SLIDER_SHIP];
-            p->slider[PLANET_SLIDER_SHIP] = 0;
+            /* p->slider[PLANET_SLIDER_TECH] += p->slider[PLANET_SLIDER_SHIP];
+            p->slider[PLANET_SLIDER_SHIP] = 0; */
+            game_turn_finished_disable_slider(g, p, PLANET_SLIDER_SHIP, false);
             game_add_planet_to_build_finished(g, pli, pi, FINISHED_STARGATE);
         }
     }
@@ -1576,6 +1632,7 @@ struct game_end_s game_turn_process(struct game_s *g)
     if ((g->year > 40) && (!rnd_0_nm1(30, &g->seed)) && (copyprot_status == 0)) {
         copyprot_status = 1;
     }
+    ui_turn_pre(g);
     game_turn_countdown_ceasefire(g);
     game_turn_update_mood_blunder(g);
     game_update_have_reserve_fuel(g);
@@ -1604,6 +1661,7 @@ struct game_end_s game_turn_process(struct game_s *g)
     game_remove_empty_fleets(g);
     game_spy_report(g);
     game_battle_handle_all(g);
+    /*game_turn_unrest_hmm1(g);*/
     for (int i = 0; i < g->players; ++i) {
         g->evn.newtech[i].num = 0;
     }
