@@ -1,13 +1,12 @@
 #include "config.h"
 
 #include <stdio.h>
-
+#include <sys/time.h>
 #include "hw.h"
 #include "cfg.h"
 #include "main.h"
 #include "options.h"
 #include "types.h"
-#include "uiopt.h"
 
 /* -------------------------------------------------------------------------- */
 
@@ -19,14 +18,6 @@ const struct cmdline_options_s hw_cmdline_options_extra[] = {
     { NULL, 0, NULL, NULL, NULL, NULL }
 };
 
-const struct uiopt_s hw_uiopts[] = {
-    UIOPT_ITEM_END
-};
-
-const struct uiopt_s hw_uiopts_extra[] = {
-    UIOPT_ITEM_END
-};
-
 const struct cfg_items_s hw_cfg_items[] = {
     CFG_ITEM_END
 };
@@ -73,12 +64,18 @@ void hw_log_error(const char *msg)
     fputs(msg, stderr);
 }
 
-uint32_t hw_get_time_us(void)
+int64_t hw_get_time_us(void)
 {
+#ifndef IS_MSDOS
+    struct timeval tv;
+    gettimeofday(&tv, NULL);
+    return (int64_t)tv.tv_usec + 1000000ll * (int64_t)tv.tv_sec;
+#else
     return 0;
+#endif
 }
 
-void hw_video_set_palette(uint8_t *palette, int first, int num)
+void hw_video_set_palette(const uint8_t *palette, int first, int num)
 {
 }
 
@@ -86,3 +83,13 @@ uint8_t *hw_video_get_buf(void)
 {
     return 0;
 }
+
+bool hw_audio_sfx_volume(int volume)
+{
+    return true;
+}
+
+bool hw_audio_music_volume(int volume)
+{
+    return true;
+}
