@@ -14,13 +14,13 @@
 
 /* -------------------------------------------------------------------------- */
 
+#define HW_DEFAULT_ASPECT   1000000
 #define HW_DEFAULT_FULLSCREEN   false
 
 #ifdef HAVE_SDL1GL
-bool hw_opt_use_gl = true;
+int hw_opt_aspect = HW_DEFAULT_ASPECT;
 int hw_opt_gl_filter = 1;
 int hw_opt_bpp = 0;
-#define HAVE_SDLX_ASPECT
 #endif /* HAVE_SDL1GL */
 
 #ifdef HAVE_SDL1MIXER
@@ -42,13 +42,38 @@ static bool hw_uiopts_filter_next(void)
     hw_opt_gl_filter = (hw_opt_gl_filter + 1) % 2;
     return true;
 }
+
+static const char *hw_uiopt_cb_aspect_get(void)
+{
+    if (hw_opt_aspect == 833333) {
+        return "VGA";
+    } else if (hw_opt_aspect == 1000000) {
+        return "1:1";
+    } else if (hw_opt_aspect == 0) {
+        return "Off";
+    } else {
+        return "Custom";
+    }
+}
+
+static bool hw_uiopt_cb_aspect_next(void)
+{
+    if (hw_opt_aspect == 833333) {
+        hw_opt_aspect = 1000000;
+    } else if (hw_opt_aspect == 1000000) {
+        hw_opt_aspect = 0;
+    } else {
+        hw_opt_aspect = 833333;
+    }
+    return hw_video_update_aspect();
+}
 #endif /* HAVE_SDL1GL */
 
 /* -------------------------------------------------------------------------- */
 
 const struct cfg_items_s hw_cfg_items_extra[] = {
 #ifdef HAVE_SDL1GL
-    CFG_ITEM_BOOL("gl", &hw_opt_use_gl),
+    CFG_ITEM_INT("aspect", &hw_opt_aspect, 0),
     CFG_ITEM_INT("bpp", &hw_opt_bpp, 0),
     CFG_ITEM_INT("filter", &hw_opt_gl_filter, 0),
 #endif /* HAVE_SDL1GL */
@@ -59,12 +84,9 @@ const struct cfg_items_s hw_cfg_items_extra[] = {
 
 const struct cmdline_options_s hw_cmdline_options_extra[] = {
 #ifdef HAVE_SDL1GL
-    { "-gl", 0,
-      options_enable_bool_var, (void *)&hw_opt_use_gl,
-      NULL, "Enable OpenGL" },
-    { "-nogl", 0,
-      options_disable_bool_var, (void *)&hw_opt_use_gl,
-      NULL, "Disable OpenGL" },
+    { "-aspect", 1,
+      options_set_int_var, (void *)&hw_opt_aspect,
+      "ASPECT", "Set aspect ratio (*1000000, 0 = off)" },
     { "-bpp", 1,
       options_set_int_var, (void *)&hw_opt_bpp,
       "BPP", "Set bits/pixel (0 = autodetect)" },
@@ -79,10 +101,8 @@ void hw_opt_menu_make_page_video(void)
 {
     menu_make_bool(menu_item_force_restart(menu_allocate_item()), "Borderless", &hw_opt_borderless, MOO_KEY_o);
     menu_make_bool_func(menu_allocate_item(), "Fullscreen", &hw_opt_fullscreen, hw_video_toggle_fullscreen, MOO_KEY_f);
-#ifdef HAVE_SDLX_ASPECT
-    menu_make_str_func(menu_allocate_item(), "Aspect ratio", hw_uiopt_cb_aspect_get, hw_uiopt_cb_aspect_next, MOO_KEY_a);
-#endif
 #ifdef HAVE_SDL1GL
+    menu_make_str_func(menu_allocate_item(), "Aspect ratio", hw_uiopt_cb_aspect_get, hw_uiopt_cb_aspect_next, MOO_KEY_a);
     menu_make_str_func(menu_allocate_item(), "Filter", hw_uiopts_filter_get, hw_uiopts_filter_next, MOO_KEY_i);
 #endif /* HAVE_SDL1GL */
 }
