@@ -218,6 +218,11 @@ static void hw_event_handle_window(SDL_WindowEvent *e)
         case SDL_WINDOWEVENT_FOCUS_LOST:
             hw_mouse_ungrab();
             break;
+        case SDL_WINDOWEVENT_FOCUS_GAINED:
+            if (!hw_opt_relmouse && hw_opt_nograbmouse) {
+                hw_mouse_grab();
+            }
+            break;
         case SDL_WINDOWEVENT_MINIMIZED:
             hw_video_set_visible(false);
             break;
@@ -352,7 +357,13 @@ int hw_event_handle(void)
                 break;
             case SDL_MOUSEMOTION:
                 if (!hw_opt_relmouse && hw_mouse_enabled) {
-                    mouse_set_xy_from_hw(e.motion.x, e.motion.y);
+                    int x, y;
+                    x = e.motion.x;
+                    y = e.motion.y;
+                    if (hw_opt_aspect_ratio_correct) {
+                        y = (y * 5 + 5) / 6;
+                    }
+                    mouse_set_xy_from_hw(x, y);
                 }
                 break;
             case SDL_MOUSEBUTTONDOWN:
