@@ -20,8 +20,8 @@
 static uint8_t *lbxfontdata = 0;
 
 static uint8_t lbxfont_temp_color = 0;
-static int lbxfont_temp_x = 0;
-static int lbxfont_temp_y = 0;
+static int16_t lbxfont_temp_x = 0;
+static int16_t lbxfont_temp_y = 0;
 static uint8_t lbxfont_current_fontnum = 0;
 static uint8_t lbxfont_current_fonta2 = 0;
 static uint8_t lbxfont_current_fonta2b = 0;
@@ -762,13 +762,6 @@ int lbxfont_print_num_right(int x, int y, int num, uint16_t pitch, int scale)
     return lbxfont_print_str_right(x, y, buf, pitch, scale);
 }
 
-int lbxfont_print_num_center_limit(int x, int y, int num, int lx0, int ly0, int lx1, int ly1, uint16_t pitch, int scale)
-{
-    char buf[16];
-    lib_sprintf(buf, sizeof(buf), "%i", num);
-    return lbxfont_print_str_center_limit(x, y, buf, lx0, ly0, lx1, ly1, pitch, scale);
-}
-
 int lbxfont_print_range_right(int x, int y, int num0, int num1, uint16_t pitch, int scale)
 {
     char buf[32];
