@@ -50,6 +50,8 @@ static int save2len = 0;
 static FILE *save2fd = 0;
 static const char *save2fname = 0;
 
+#define SAVE2BUF_SIZE 0x10000
+
 typedef enum {
     SAVETYPE_SMART = 0,
     SAVETYPE_MOO13,
@@ -658,7 +660,6 @@ static int savetype_de_moo13(struct game_s *g, const char *fname)
         M13_GET_TBL_16(ev->spies_caught[PLAYER_0], evb + 0x1fe);
         M13_GET_TBL_16(ev->ceasefire[PLAYER_0], evb + 0x28e);
         M13_GET_TBL_BVN_8(ev->help_shown[PLAYER_0], evb + 0x2e2, 16);
-        ev->msg_filter[PLAYER_0][0] = FINISHED_DEFAULT_FILTER;
         /* TODO build_finished ; is it even possible to save before clicking them away? */
         M13_GET_TBL_16_OWNER(ev->voted, evb + 0x320);
         M13_GET_16(ev->best_ecorestore[PLAYER_0], evb + 0x32c);
@@ -709,8 +710,7 @@ static int savetype_de_moo13(struct game_s *g, const char *fname)
                 }
             }
             if (found) {
-                strncpy(savename, (const char *)&cmoobuf[0x22 + 20 * (savei - 1)], SAVE_NAME_LEN);
-                savename[SAVE_NAME_LEN - 1] = '\0';
+                lib_strcpy(savename, (const char *)&cmoobuf[0x22 + 20 * (savei - 1)], SAVE_NAME_LEN);
                 LOG_DEBUG((1, "found '%s' slot %i '%s'\n", tryname, savei, savename));
             }
             if (fullname) {
@@ -721,7 +721,7 @@ static int savetype_de_moo13(struct game_s *g, const char *fname)
         lib_free(fnam);
         lib_free(dir);
         if ((savename[0] == 0) && (savei >= 1) && (savei <= 7)) {
-            sprintf(savename, "v1.3 SAVE%i.GAM", savei);
+            lib_sprintf(savename, SAVE_NAME_LEN, "v1.3 SAVE%i.GAM", savei);
             LOG_DEBUG((1, "generated '%s' -> '%s'\n", fname, savename));
         }
     }
@@ -1259,7 +1259,6 @@ static const struct game_intros_s game_intros_planet[] = {
     GAME_INTROS_VAL(planet_s, buildship),
     GAME_INTROS_VAL(planet_s, reloc),
     GAME_INTROS_VAL(planet_s, missile_bases),
-    GAME_INTROS_VAL(planet_s, target_bases),
     GAME_INTROS_VAL(planet_s, bc_to_base),
     GAME_INTROS_VAL(planet_s, bc_upgrade_base),
     GAME_INTROS_VAL(planet_s, have_stargate),
@@ -1274,7 +1273,6 @@ static const struct game_intros_s game_intros_planet[] = {
     GAME_INTROS_VAL(planet_s, unrest),
     GAME_INTROS_VAL(planet_s, unrest_reported),
     GAME_INTROS_BV(planet_s, finished, FINISHED_NUM),
-    GAME_INTROS_BV(planet_s, extras, PLANET_EXTRAS_NUM),
     GAME_INTROS_END
 };
 
@@ -1466,11 +1464,6 @@ static const struct game_intros_s game_intros_help_shown[] = {
     GAME_INTROS_END
 };
 
-static const struct game_intros_s game_intros_msg_filter[] = {
-    { "", GAME_INTROS_T_BV, 0, FINISHED_NUM, 1, 0 },
-    GAME_INTROS_END
-};
-
 static const struct game_intros_s game_intros_evn[] = {
     GAME_INTROS_VAL(gameevents_s, year),
     GAME_INTROS_BV(gameevents_s, done, GAME_EVENT_TBL_NUM),
@@ -1505,9 +1498,6 @@ static const struct game_intros_s game_intros_evn[] = {
     GAME_INTROS_SUB(gameevents_s, spies_caught, game_intros_spies_caught),
     GAME_INTROS_SUB(gameevents_s, ceasefire, game_intros_ceasefire),
     GAME_INTROS_SUB(gameevents_s, help_shown, game_intros_help_shown),
-    GAME_INTROS_SUB(gameevents_s, msg_filter, game_intros_msg_filter),
-    GAME_INTROS_TBL(gameevents_s, gov_eco_mode),
-    GAME_INTROS_BV(gameevents_s, gov_no_stargates, PLAYER_NUM),
     GAME_INTROS_TBL(gameevents_s, build_finished_num),
     GAME_INTROS_TBL(gameevents_s, voted),
     GAME_INTROS_TBL(gameevents_s, best_ecorestore),
@@ -1925,7 +1915,7 @@ fail:
     return -1;
 }
 
-#define OUTADD  save2len += sprintf((char *)&save2buf[save2len],
+#define OUTADD  save2len += lib_sprintf((char *)&save2buf[save2len], SAVE2BUF_SIZE - save2len,
 #define OUTPRE()    OUTADD "%s", tp->buf)
 #define OUTLINE OUTPRE(); OUTADD
 #define OUTLINEI(_name_, _var_) OUTPRE(); OUTADD "%s = %i\n", _name_, _var_)
@@ -1967,15 +1957,20 @@ static void text_dump_prefix_add(struct text_dump_prefix_s *tp, const char *str,
 {
     int num, pos;
     num = tp->num++;
+    if (num >= 10) {
+        log_fatal_and_die("test_dump_prefix_add: too many entries.");
+    }
     pos = tp->pos[num];
-    pos += sprintf(&(tp->buf[pos]), "%s%s", str, sep);
-    tp->pos[num + 1] = pos;
+    pos += lib_sprintf(&(tp->buf[pos]), 128 - pos, "%s%s", str, sep);
+    if (num <= 8) {
+        tp->pos[num + 1] = pos;
+    }
 }
 
 static void text_dump_prefix_add_tbl(struct text_dump_prefix_s *tp, const char *str, const char *sep, int index)
 {
     char buf[128];
-    sprintf(buf, "%s[%i]", str, index);
+    lib_sprintf(buf, sizeof(buf), "%s[%i]", str, index);
     text_dump_prefix_add(tp, buf, sep);
 }
 
@@ -2125,7 +2120,6 @@ static int savetype_en_text(struct game_s *g, const char *fname)
         OUTLINEI("buildship", p->buildship);
         OUTLINEI("reloc", p->reloc);
         OUTLINEI("missile_bases", p->missile_bases);
-        OUTLINEI("target_bases", p->target_bases);
         OUTLINEI("bc_to_base", p->bc_to_base);
         OUTLINEI("bc_upgrade_base", p->bc_upgrade_base);
         OUTLINEI("have_stargate", p->have_stargate);
@@ -2140,7 +2134,6 @@ static int savetype_en_text(struct game_s *g, const char *fname)
         OUTLINEI("unrest", p->unrest);
         OUTLINEI("unrest_reported", p->unrest_reported);
         OUTLINEBV("finished", p->finished, FINISHED_NUM);
-        OUTLINEBV("extras", p->extras, PLANET_EXTRAS_NUM);
         text_dump_prefix_del(tp);
         OUTFLUSH();
     }
@@ -2340,13 +2333,8 @@ static int savetype_en_text(struct game_s *g, const char *fname)
                 text_dump_prefix_add_tbl(tp, "help_shown", "", pl);
                 OUTLINEBV("", ev->help_shown[pl], HELP_SHOWN_NUM);
                 text_dump_prefix_del(tp);
-                text_dump_prefix_add_tbl(tp, "msg_filter", "", pl);
-                OUTLINEBV("", ev->msg_filter[pl], FINISHED_NUM);
-                text_dump_prefix_del(tp);
             }
         }
-        OUTLINETBL("gov_eco_mode", g->players, ev->gov_eco_mode);
-        OUTLINEBV("gov_no_stargates", ev->gov_no_stargates, g->players);
         OUTLINETBL("build_finished_num", g->players, ev->build_finished_num);
         OUTLINETBL("voted", g->players, ev->voted);
         OUTLINETBL("best_ecorestore", g->players, ev->best_ecorestore);
@@ -2487,11 +2475,22 @@ const struct cmdline_options_s main_cmdline_options[] = {
 
 struct pbx_add_cbs;
 
+/* Dummy functions that are needed because some of the headers slip in pbx.h. */
 int pbx_add_file(const char *filename, struct pbx_add_cbs *cbs)
 {
     return -1;
 }
 
+int pbx_queue_file(const char *filename)
+{
+    return -1;
+}
+
+int pbx_apply_queued_files(void)
+{
+    return -1;
+}
+
 /* -------------------------------------------------------------------------- */
 
 static int main_early_init(void)
@@ -2507,7 +2506,7 @@ static int main_early_init(void)
     gaux->savenamebuf = lib_malloc(gaux->savenamebuflen);
     gaux->savebuflen = sizeof(struct game_s) + 64;
     gaux->savebuf = lib_malloc(gaux->savebuflen);
-    save2buf = lib_malloc(0x10000);
+    save2buf = lib_malloc(SAVE2BUF_SIZE);
     return 0;
 }
 
@@ -2548,12 +2547,12 @@ int main_do(void)
             fname = gameptr->gaux->savenamebuf;
         }
     }
-    LOG_DEBUG((1, "%s: decode type '%s' file '%s'\n", __func__, savetype[savetypei].name, fname));
     res = savetype[savetypei].decode(gameptr, fname);
     if (res < 0) {
         log_error("decoding file '%s' failed\n", fname);
         return 1;
     }
+    log_message("saveconv: decode type '%s' file '%s'\n", savetype[savetypei].name, fname);
     if (!savetype[savetypeo].encode) {
         LOG_DEBUG((1, "%s: encode type '%s' no callback\n", __func__, savetype[savetypeo].name));
         if (main_fname_num == 2) {
@@ -2577,9 +2576,9 @@ int main_do(void)
             fname = gameptr->gaux->savenamebuf;
         }
     }
-    LOG_DEBUG((1, "%s: encode type '%s' file '%s'\n", savetype[savetypeo].name, fname ? fname : "(null)"));
+    log_message("saveconv: encode type '%s' file '%s'\n", savetype[savetypeo].name, fname ? fname : "(null)");
     if (savename[0] == '\0') {
-        strcpy(savename, "saveconv");
+        lib_strcpy(savename, "saveconv", SAVE_NAME_LEN);
     }
     res = savetype[savetypeo].encode(gameptr, fname);
     if (res < 0) {
