@@ -35,6 +35,7 @@ typedef enum {
     MAIN_MENU_ACT_CUSTOM_GAME,
     MAIN_MENU_ACT_CHALLENGE_GAME,
     MAIN_MENU_ACT_LOAD_GAME,
+    MAIN_MENU_ACT_LOAD_GAME_MOO13,
     MAIN_MENU_ACT_CONTINUE_GAME,
     MAIN_MENU_ACT_QUIT_GAME,
     MAIN_MENU_ACT_TUTOR
@@ -150,9 +151,12 @@ extern int ui_spy_sabotage_done(struct game_s *g, int pi, int spy, int target, u
 extern void ui_newtech(struct game_s *g, int pi);
 
 extern bool ui_explore(struct game_s *g, int pi, uint8_t planet_i, bool by_scanner, bool flag_colony_ship);
+extern void ui_landing(struct game_s *g, int pi, uint8_t planet_i);
+
 extern bool ui_bomb_ask(struct game_s *g, int pi, uint8_t planet_i, int pop_inbound);
 extern void ui_bomb_show(struct game_s *g, int pi, int attacker_i, int owner_i, uint8_t planet_i, int popdmg, int factdmg, bool play_music, bool hide_other);
 
+extern void ui_turn_pre(const struct game_s *g);
 extern void ui_turn_msg(struct game_s *g, int pi, const char *str);
 
 struct ground_s;
