@@ -58,6 +58,7 @@ typedef enum {
 typedef enum {
     UI_SM_STAR_TEXT_NAME,
     UI_SM_STAR_TEXT_POPULATION,
+    UI_SM_STAR_TEXT_DISTANCE,
     UI_SM_STAR_TEXT_ENVIRONMENT,
     UI_SM_STAR_TEXT_SPECIAL,
     UI_SM_STAR_TEXT_NUM,
@@ -305,14 +306,15 @@ extern bool ui_load_opts_extra;
 extern bool ui_space_combat_autoresolve;
 extern bool ui_sm_ships_enabled;
 extern bool ui_sm_expanded_scroll;
-extern bool ui_sm_distance_tooltip;
 extern bool ui_sm_no_question_mark_cursor;
 extern bool ui_sm_explicit_cursor_context;
 extern bool ui_mouse_lmb_fix;
 extern bool ui_mouse_warp_disabled;
 extern bool ui_copyprotection_disabled;
 extern bool ui_sm_mouseover_focus;
+extern bool ui_sm_smoother_scrolling;
 extern bool ui_sm_mouse_scroll;
+extern bool ui_sm_uhjk_scroll;
 extern bool ui_kbd_cursor_keys_fix;
 extern bool ui_mwi_slider;
 extern bool ui_mwi_counter;
