@@ -226,7 +226,7 @@ static void design_draw_cb(void *vptr)
     }
     if (sd->shield) {
         uint8_t v = tbl_shiptech_shield[sd->shield].absorb;
-        sprintf(buf, "%s %i %s", game_str_sd_absorbs, v, (v == 1) ? game_str_sd_hit : game_str_sd_hits);
+        lib_sprintf(buf, sizeof(buf), "%s %i %s", game_str_sd_absorbs, v, (v == 1) ? game_str_sd_hit : game_str_sd_hits);
         lbxfont_print_str_normal(101, 34, buf, UI_SCREEN_W, ui_scale);
     }
     lbxfont_print_str_normal(101, 46, game_str_sd_misdef, UI_SCREEN_W, ui_scale);
@@ -294,7 +294,7 @@ static void design_init_ois(struct ui_design_data_s *u)
     u->oi_icon = uiobj_add_mousearea(89, 161, 128, 192, MOO_KEY_UNKNOWN);
     u->oi_iscroll = uiobj_add_mousewheel(89, 161, 150, 192, &u->scroll);
     lbxfont_select(2, 6, 0, 3);
-    u->oi_cancel = uiobj_add_t0(282, 150, game_str_sd_cancel, ui_data.gfx.design.blank, MOO_KEY_SPACE);
+    u->oi_cancel = uiobj_add_t0(282, 150, game_str_sd_cancel, ui_data.gfx.design.blank, MOO_KEY_ESCAPE);
     u->oi_build = uiobj_add_t0(282, 182, game_str_sd_build, ui_data.gfx.design.blank, MOO_KEY_b);
     u->oi_clear = uiobj_add_t0(282, 166, game_str_sd_clear, ui_data.gfx.design.blank, MOO_KEY_c);
     lbxfont_select(0, 0, 5, 3);
@@ -342,7 +342,11 @@ static struct xy_s ui_design_draw_selbox(int xpos, int xoff1, int xoff2, int xof
     SETMIN(x1, 159);
     SETMAX(y0, 0);
 
-    ui_cursor_erase1(); /* HACK should not be needed */
+    if (ui_extra_enabled) {
+        hw_video_copy_back_from_page3();
+    } else {
+        ui_cursor_erase1(); /* HACK should not be needed */
+    }
     ui_draw_box_grain(x0 + 4, y0 + 4, x0 + xpos + xoff2, y1 + 20, 1, 2, 0x37, ui_scale);
     /*uiobj_set_limits(x0, y0, x1, y1);*/
     lbxgfx_draw_frame_offs(x0, y0, ui_data.gfx.design.pop1_ul, x0, y0, x1, y1, UI_SCREEN_W, ui_scale);
@@ -376,13 +380,14 @@ static void ui_design_sel_comp(struct design_data_s *d)
     char titlebuf[0x80];
     char linebuf[SHIP_COMP_NUM * 0x50];
     const char *lineptr[SHIP_COMP_NUM + 1];
+    struct strbuild_s line_builder = strbuild_init(linebuf, sizeof(linebuf));
     shipdesign_t *sd = &(d->gd->sd);
     ship_comp_t actcomp = sd->comp;
 
     lbxfont_select(2, 0, 4, 0xe);
 
     {
-        int havelast, space, cost, bufpos = 0;
+        int havelast, space, cost;
         char s1[3] = "\x1dX";
         char s2[3] = "\x1dX";
         char s3[3] = "\x1dX";
@@ -407,9 +412,10 @@ static void ui_design_sel_comp(struct design_data_s *d)
         cost = game_design_calc_cost(d->gd);
         havelast = game_design_build_tbl_fit_comp(d->g, d->gd, havebuf);
 
+        /* game_design_build_tbl_fit_comp ensures that havelast < SHIP_COMP_NUM. */
         for (int i = 0; i <= havelast; ++i) {
             if (havebuf[i] >= 0) {
-                int space2, power, cost2, sizei, len;
+                int space2, power, cost2, sizei;
                 flag_tbl_enable[n] = (havebuf[i] > 0);
                 if (i == actcomp) {
                     curcomp = n;
@@ -421,14 +427,12 @@ static void ui_design_sel_comp(struct design_data_s *d)
                 power = tbl_shiptech_comp[i].power[sd->hull];
                 cost2 = game_design_calc_cost(d->gd) - cost;
                 sizei = game_design_calc_space_item(d->gd, DESIGN_SLOT_COMP, i);
-                len = sprintf(&linebuf[bufpos], "%s%s%i%s%i%s%i%s%i", *tbl_shiptech_comp[i].nameptr, s1, cost2, s2, sizei, s3, power, s4, space2);
-                lineptr[n] = &linebuf[bufpos];
-                bufpos += len + 1;
-                ++n;
+                strbuild_catf(&line_builder, "%s%s%i%s%i%s%i%s%i", *tbl_shiptech_comp[i].nameptr, s1, cost2, s2, sizei, s3, power, s4, space2);
+                lineptr[n++] = strbuild_finish(&line_builder);
             }
         }
-        lineptr[n] = 0;
-        sprintf(titlebuf, "%s%s%s%s%s%s%s%s%s", game_str_sd_comptype, s1, game_str_sd_cost, s2, game_str_sd_size, s3, game_str_sd_power, s4, game_str_sd_space);
+        lineptr[n] = NULL;
+        lib_sprintf(titlebuf, sizeof(titlebuf), "%s%s%s%s%s%s%s%s%s", game_str_sd_comptype, s1, game_str_sd_cost, s2, game_str_sd_size, s3, game_str_sd_power, s4, game_str_sd_space);
     }
     {
         int listi;
@@ -454,13 +458,14 @@ static void ui_design_sel_shield(struct design_data_s *d)
     char titlebuf[0x80];
     char linebuf[SHIP_SHIELD_NUM * 0x50];
     const char *lineptr[SHIP_SHIELD_NUM + 1];
+    struct strbuild_s line_builder = strbuild_init(linebuf, sizeof(linebuf));
     shipdesign_t *sd = &(d->gd->sd);
     ship_shield_t actshield = sd->shield;
 
     lbxfont_select(2, 0, 4, 0xe);
 
     {
-        int havelast, space, cost, bufpos = 0;
+        int havelast, space, cost;
         char s1[3] = "\x1dX";
         char s2[3] = "\x1dX";
         char s3[3] = "\x1dX";
@@ -485,9 +490,10 @@ static void ui_design_sel_shield(struct design_data_s *d)
         cost = game_design_calc_cost(d->gd);
         havelast = game_design_build_tbl_fit_shield(d->g, d->gd, havebuf);
 
+        /* game_design_build_tbl_fit_shield ensures that havelast < SHIP_SHIELD_NUM. */
         for (int i = 0; i <= havelast; ++i) {
             if (havebuf[i] >= 0) {
-                int space2, power, cost2, sizei, len;
+                int space2, power, cost2, sizei;
                 flag_tbl_enable[n] = (havebuf[i] > 0);
                 if (i == actshield) {
                     curshield = n;
@@ -499,14 +505,12 @@ static void ui_design_sel_shield(struct design_data_s *d)
                 power = tbl_shiptech_shield[i].power[sd->hull];
                 cost2 = game_design_calc_cost(d->gd) - cost;
                 sizei = game_design_calc_space_item(d->gd, DESIGN_SLOT_SHIELD, i);
-                len = sprintf(&linebuf[bufpos], "%s%s%i%s%i%s%i%s%i", *tbl_shiptech_shield[i].nameptr, s1, cost2, s2, sizei, s3, power, s4, space2);
-                lineptr[n] = &linebuf[bufpos];
-                bufpos += len + 1;
-                ++n;
+                strbuild_catf(&line_builder, "%s%s%i%s%i%s%i%s%i", *tbl_shiptech_shield[i].nameptr, s1, cost2, s2, sizei, s3, power, s4, space2);
+                lineptr[n++] = strbuild_finish(&line_builder);
             }
         }
-        lineptr[n] = 0;
-        sprintf(titlebuf, "%s%s%s%s%s%s%s%s%s", game_str_sd_shieldtype, s1, game_str_sd_cost, s2, game_str_sd_size, s3, game_str_sd_power, s4, game_str_sd_space);
+        lineptr[n] = NULL;
+        lib_sprintf(titlebuf, sizeof(titlebuf), "%s%s%s%s%s%s%s%s%s", game_str_sd_shieldtype, s1, game_str_sd_cost, s2, game_str_sd_size, s3, game_str_sd_power, s4, game_str_sd_space);
     }
     {
         int listi;
@@ -532,13 +536,14 @@ static void ui_design_sel_jammer(struct design_data_s *d)
     char titlebuf[0x80];
     char linebuf[SHIP_JAMMER_NUM * 0x50];
     const char *lineptr[SHIP_SHIELD_NUM + 1];
+    struct strbuild_s line_builder = strbuild_init(linebuf, sizeof(linebuf));
     shipdesign_t *sd = &(d->gd->sd);
-    ship_shield_t actjammer = sd->jammer;
+    ship_jammer_t actjammer = sd->jammer;
 
     lbxfont_select(2, 0, 4, 0xe);
 
     {
-        int havelast, space, cost, bufpos = 0;
+        int havelast, space, cost;
         char s1[3] = "\x1dX";
         char s2[3] = "\x1dX";
         char s3[3] = "\x1dX";
@@ -563,9 +568,10 @@ static void ui_design_sel_jammer(struct design_data_s *d)
         cost = game_design_calc_cost(d->gd);
         havelast = game_design_build_tbl_fit_jammer(d->g, d->gd, havebuf);
 
+        /* game_design_build_tbl_fit_jammer ensures that havelast < SHIP_JAMMER_NUM. */
         for (int i = 0; i <= havelast; ++i) {
             if (havebuf[i] >= 0) {
-                int space2, power, cost2, sizei, len;
+                int space2, power, cost2, sizei;
                 flag_tbl_enable[n] = (havebuf[i] > 0);
                 if (i == actjammer) {
                     curjammer = n;
@@ -577,14 +583,12 @@ static void ui_design_sel_jammer(struct design_data_s *d)
                 power = tbl_shiptech_jammer[i].power[sd->hull];
                 cost2 = game_design_calc_cost(d->gd) - cost;
                 sizei = game_design_calc_space_item(d->gd, DESIGN_SLOT_JAMMER, i);
-                len = sprintf(&linebuf[bufpos], "%s%s%i%s%i%s%i%s%i", *tbl_shiptech_jammer[i].nameptr, s1, cost2, s2, sizei, s3, power, s4, space2);
-                lineptr[n] = &linebuf[bufpos];
-                bufpos += len + 1;
-                ++n;
+                strbuild_catf(&line_builder, "%s%s%i%s%i%s%i%s%i", *tbl_shiptech_jammer[i].nameptr, s1, cost2, s2, sizei, s3, power, s4, space2);
+                lineptr[n++] = strbuild_finish(&line_builder);
             }
         }
-        lineptr[n] = 0;
-        sprintf(titlebuf, "%s%s%s%s%s%s%s%s%s", game_str_sd_ecmtype, s1, game_str_sd_cost, s2, game_str_sd_size, s3, game_str_sd_power, s4, game_str_sd_space);
+        lineptr[n] = NULL;
+        lib_sprintf(titlebuf, sizeof(titlebuf), "%s%s%s%s%s%s%s%s%s", game_str_sd_ecmtype, s1, game_str_sd_cost, s2, game_str_sd_size, s3, game_str_sd_power, s4, game_str_sd_space);
     }
     {
         int listi;
@@ -604,19 +608,20 @@ static void ui_design_sel_armor(struct design_data_s *d)
 {
     int8_t havebuf[SHIP_ARMOR_NUM];
     bool flag_tbl_enable[SHIP_ARMOR_NUM];
-    ship_jammer_t tbl_armor[SHIP_ARMOR_NUM];
+    ship_armor_t tbl_armor[SHIP_ARMOR_NUM];
     int xpos, n = 0;
     int16_t curarmor;
     char titlebuf[0x80];
     char linebuf[SHIP_ARMOR_NUM * 0x50];
     const char *lineptr[SHIP_ARMOR_NUM + 1];
+    struct strbuild_s line_builder = strbuild_init(linebuf, sizeof(linebuf));
     shipdesign_t *sd = &(d->gd->sd);
-    ship_shield_t actarmor = sd->armor;
+    ship_armor_t actarmor = sd->armor;
 
     lbxfont_select(2, 0, 4, 0xe);
 
     {
-        int havelast, bufpos = 0;
+        int havelast;
         char s1[3] = "\x1dX";
         char s2[3] = "\x1dX";
 
@@ -631,9 +636,11 @@ static void ui_design_sel_armor(struct design_data_s *d)
         s2[1] = (char)(xpos + 50);
 
         havelast = game_design_build_tbl_fit_armor(d->g, d->gd, havebuf);
+
+        /* game_design_build_tbl_fit_armor ensures that havelast < SHIP_ARMOR_NUM. */
         for (int i = 0; i <= havelast; ++i) {
             if (havebuf[i] >= 0) {
-                int cost2, sizei, len;
+                int cost2, sizei;
                 flag_tbl_enable[n] = (havebuf[i] > 0);
                 if (i == actarmor) {
                     curarmor = n;
@@ -643,14 +650,12 @@ static void ui_design_sel_armor(struct design_data_s *d)
                 game_design_update_engines(sd);
                 cost2 = game_design_calc_cost_item(d->gd, DESIGN_SLOT_ARMOR, i);
                 sizei = game_design_calc_space_item(d->gd, DESIGN_SLOT_ARMOR, i);
-                len = sprintf(&linebuf[bufpos], "%s%s%i%s%i", *tbl_shiptech_armor[i].nameptr, s1, cost2, s2, sizei);
-                lineptr[n] = &linebuf[bufpos];
-                bufpos += len + 1;
-                ++n;
+                strbuild_catf(&line_builder, "%s%s%i%s%i", *tbl_shiptech_armor[i].nameptr, s1, cost2, s2, sizei);
+                lineptr[n++] = strbuild_finish(&line_builder);
             }
         }
-        lineptr[n] = 0;
-        sprintf(titlebuf, "%s%s%s%s%s", game_str_sd_armortype, s1, game_str_sd_cost, s2, game_str_sd_size);
+        lineptr[n] = NULL;
+        lib_sprintf(titlebuf, sizeof(titlebuf), "%s%s%s%s%s", game_str_sd_armortype, s1, game_str_sd_cost, s2, game_str_sd_size);
     }
     {
         int listi;
@@ -676,13 +681,14 @@ static void ui_design_sel_engine(struct design_data_s *d)
     char titlebuf[0x80];
     char linebuf[SHIP_ENGINE_NUM * 0x50];
     const char *lineptr[SHIP_ENGINE_NUM + 1];
+    struct strbuild_s line_builder = strbuild_init(linebuf, sizeof(linebuf));
     shipdesign_t *sd = &(d->gd->sd);
     ship_engine_t actengine = sd->engine;
 
     lbxfont_select(2, 0, 4, 0xe);
 
     {
-        int havelast, bufpos = 0;
+        int havelast;
         char s1[3] = "\x1dX";
         char s2[3] = "\x1dX";
         char s3[3] = "\x1dX";
@@ -704,9 +710,10 @@ static void ui_design_sel_engine(struct design_data_s *d)
         game_design_update_engines(sd);
         havelast = game_design_build_tbl_fit_engine(d->g, d->gd, havebuf);
 
+        /* game_design_build_tbl_fit_engine ensures that havelast < SHIP_ENGINE_NUM. */
         for (int i = 0; i <= havelast; ++i) {
             if (havebuf[i] >= 0) {
-                int cost2, sizei, sizet, ne, len;
+                int cost2, sizei, sizet, ne;
                 flag_tbl_enable[n] = (havebuf[i] > 0);
                 if (i == actengine) {
                     curengine = n;
@@ -718,14 +725,12 @@ static void ui_design_sel_engine(struct design_data_s *d)
                 sizei = game_design_calc_space_item(d->gd, DESIGN_SLOT_ENGINE, i);
                 sizet = (sizei * ne) / 10;
                 cost2 = game_design_calc_cost_item(d->gd, DESIGN_SLOT_ENGINE, i);
-                len = sprintf(&linebuf[bufpos], "%s%s%i%s%i%s%i.%i%s%i", *tbl_shiptech_engine[i].nameptr, s1, cost2, s2, sizei, s3, ne / 10, ne % 10, s4, sizet);
-                lineptr[n] = &linebuf[bufpos];
-                bufpos += len + 1;
-                ++n;
+                strbuild_catf(&line_builder, "%s%s%i%s%i%s%i.%i%s%i", *tbl_shiptech_engine[i].nameptr, s1, cost2, s2, sizei, s3, ne / 10, ne % 10, s4, sizet);
+                lineptr[n++] = strbuild_finish(&line_builder);
             }
         }
-        lineptr[n] = 0;
-        sprintf(titlebuf, "%s%s%s%s%s%s%s%s%s", game_str_sd_engtype, s1, game_str_sd_cost, s2, game_str_sd_size, s3, game_str_sd_numengs, s4, game_str_sd_space);
+        lineptr[n] = NULL;
+        lib_sprintf(titlebuf, sizeof(titlebuf), "%s%s%s%s%s%s%s%s%s", game_str_sd_engtype, s1, game_str_sd_cost, s2, game_str_sd_size, s3, game_str_sd_numengs, s4, game_str_sd_space);
     }
     {
         int listi;
@@ -749,13 +754,14 @@ static void ui_design_sel_man(struct design_data_s *d)
     char titlebuf[0x80];
     char linebuf[SHIP_ENGINE_NUM * 0x50];
     const char *lineptr[SHIP_ENGINE_NUM + 1];
+    struct strbuild_s line_builder = strbuild_init(linebuf, sizeof(linebuf));
     shipdesign_t *sd = &(d->gd->sd);
     ship_engine_t actman = sd->man;
 
     lbxfont_select(2, 0, 4, 0xe);
 
     {
-        int havelast = sd->engine, bufpos = 0, powperwarp, space, cost;
+        int havelast = sd->engine, powperwarp, space, cost;
         char s1[3] = "\x1dX";
         char s2[3] = "\x1dX";
         char s3[3] = "\x1dX";
@@ -764,7 +770,7 @@ static void ui_design_sel_man(struct design_data_s *d)
         xpos = 0;
         for (int i = 0; i <= havelast; ++i) {
             int w;
-            sprintf(linebuf, "%s %s", game_str_sd_class, game_str_tbl_roman[i + 1]);
+            lib_sprintf(linebuf, sizeof(linebuf), "%s %s", game_str_sd_class, game_str_tbl_roman[i + 1]);
             w = lbxfont_calc_str_width(linebuf);
             SETMAX(xpos, w);
         }
@@ -784,7 +790,7 @@ static void ui_design_sel_man(struct design_data_s *d)
         cost = game_design_calc_cost(d->gd);
 
         for (int i = 0; i <= havelast; ++i) {
-            int cost2, space2, spacet, len;
+            int cost2, space2, spacet;
             sd->man = i;
             game_design_update_engines(sd);
             spacet = game_design_calc_space(d->gd);
@@ -798,13 +804,11 @@ static void ui_design_sel_man(struct design_data_s *d)
             SETMAX(powperwarp, 1);
             cost2 = game_design_calc_cost(d->gd) - cost;
             SETMAX(cost2, 1);
-            len = sprintf(&linebuf[bufpos], "%s %s%s%i%s%i%s%i%s%i", game_str_sd_class, game_str_tbl_roman[i + 1], s1, (i + 3) / 2, s2, cost2, s3, powperwarp, s4, space2);
-            lineptr[n] = &linebuf[bufpos];
-            bufpos += len + 1;
-            ++n;
+            strbuild_catf(&line_builder, "%s %s%s%i%s%i%s%i%s%i", game_str_sd_class, game_str_tbl_roman[i + 1], s1, (i + 3) / 2, s2, cost2, s3, powperwarp, s4, space2);
+            lineptr[n++] = strbuild_finish(&line_builder);
         }
-        lineptr[n] = 0;
-        sprintf(titlebuf, "%s%s%s%s%s%s%s%s%s", game_str_sd_man1, s1, game_str_sd_speed, s2, game_str_sd_cost, s3, game_str_sd_power, s4, game_str_sd_space);
+        lineptr[n] = NULL;
+        lib_sprintf(titlebuf, sizeof(titlebuf), "%s%s%s%s%s%s%s%s%s", game_str_sd_man1, s1, game_str_sd_speed, s2, game_str_sd_cost, s3, game_str_sd_power, s4, game_str_sd_space);
     }
     {
         int listi;
@@ -825,19 +829,25 @@ static void ui_design_sel_weapon(struct design_data_s *d, int wslot)
     int8_t havebuf[WEAPON_NUM];
     bool flag_tbl_enable[WEAPON_NUM];
     weapon_t tbl_weapon[WEAPON_NUM];
-    int xpos, xpos2, n = 0, numlines = 0;
+    int xpos, xpos2, n, numlines;
     int16_t curweap;
     char titlebuf[0x80];
     char linebuf[WEAPON_NUM * 0x58];
     const char *lineptr[WEAPON_NUM + 1];
+    struct strbuild_s line_builder;
     shipdesign_t *sd = &(d->gd->sd);
     weapon_t actwpnt = sd->wpnt[wslot];
     uint8_t actwpnn = sd->wpnn[wslot];
 
+    again:
+    n = 0;
+    numlines = 0;
+    curweap = 0;
+    line_builder = strbuild_init(linebuf, sizeof(linebuf));
     lbxfont_select(2, 0, 4, 0xe);
 
     {
-        int havelast, bufpos = 0, space, cost;
+        int havelast, space, cost;
         char s1[3] = "\x1dX";
         char s2[3] = "\x1dX";
         char s3[3] = "\x1dX";
@@ -869,7 +879,13 @@ static void ui_design_sel_weapon(struct design_data_s *d, int wslot)
         game_design_update_engines(sd);
         space = game_design_calc_space(d->gd);
         cost = game_design_calc_cost(d->gd);
-        havelast = game_design_build_tbl_fit_weapon(d->g, d->gd, havebuf, wslot);
+        havelast = 0;
+        while (!havelast) {
+            havelast = game_design_build_tbl_fit_weapon(d->g, d->gd, havebuf, wslot, ui_data.sorted.weapon_type[d->api]);
+            if (!havelast) {
+                ui_data.sorted.weapon_type[d->api] = (ui_data.sorted.weapon_type[d->api] + 1) % WEAPON_GROUP_NUM;
+            }
+        }
 
         {
             int i = havelast + 1, firsti;
@@ -889,9 +905,11 @@ static void ui_design_sel_weapon(struct design_data_s *d, int wslot)
                 firsti = 0;
                 i = 0;
             }
+
+            /* game_design_build_tbl_fit_weapon ensures that havelast < WEAPON_NUM. */
             while (i <= havelast) {
                 if (havebuf[i] >= 0) {
-                    int space2, cost2, power, sizei, len, dmin, dmax;
+                    int space2, cost2, power, sizei, dmin, dmax;
                     ++numlines;
                     sd->wpnt[wslot] = i;
                     sd->wpnn[wslot] = 1;
@@ -910,16 +928,12 @@ static void ui_design_sel_weapon(struct design_data_s *d, int wslot)
                     sizei = game_design_calc_space_item(d->gd, DESIGN_SLOT_WEAPON1, i);
                     dmin = tbl_shiptech_weap[i].damagemin;
                     dmax = tbl_shiptech_weap[i].damagemax;
-                    lineptr[n] = &linebuf[bufpos];
-                    len = sprintf(&linebuf[bufpos], "%i%s%s%s%s%s%i", havebuf[i], s1, *tbl_shiptech_weap[i].nameptr, s2, *tbl_shiptech_weap[i].extratextptr, s3, dmin);
-                    bufpos += len;
+                    strbuild_catf(&line_builder, "%i%s%s%s%s%s%i", havebuf[i], s1, *tbl_shiptech_weap[i].nameptr, s2, *tbl_shiptech_weap[i].extratextptr, s3, dmin);
                     if (dmin != dmax) {
-                        len = sprintf(&linebuf[bufpos], "-%i", dmax);
-                        bufpos += len;
+                        strbuild_catf(&line_builder, "-%i", dmax);
                     }
-                    len = sprintf(&linebuf[bufpos], "%s%i%s%i%s%i%s      %i", s4, cost2, s5, sizei, s6, power, s7, space2);
-                    bufpos += len + 1;
-                    ++n;
+                    strbuild_catf(&line_builder, "%s%i%s%i%s%i%s      %i", s4, cost2, s5, sizei, s6, power, s7, space2);
+                    lineptr[n++] = strbuild_finish(&line_builder);
                 }
                 ++i;
                 if ((firsti > 0) && (i == 1)) {
@@ -928,19 +942,22 @@ static void ui_design_sel_weapon(struct design_data_s *d, int wslot)
             }
         }
         lineptr[n] = 0;
-        sprintf(titlebuf, "%s %s%s%s%s%s%s%s%s%s%s%s%s      %s", game_str_sd_max, game_str_sd_weapname, s2, game_str_sd_descr, s3, game_str_sd_dmg, s4, game_str_sd_cost, s5, game_str_sd_size, s6, game_str_sd_power, s7, game_str_sd_space);
+        lib_sprintf(titlebuf, sizeof(titlebuf), "%s %s%s%s%s%s%s%s%s%s%s%s%s      %s", game_str_sd_max, game_str_sd_weapname, s2, game_str_sd_descr, s3, game_str_sd_dmg, s4, game_str_sd_cost, s5, game_str_sd_size, s6, game_str_sd_power, s7, game_str_sd_space);
     }
     {
         int listi;
         struct xy_s xy;
         SETMIN(n, 18);
-        xy = ui_design_draw_selbox(xpos, 160, 160, 0, n + 2, game_str_sd_weaps);
+        xy = ui_design_draw_selbox(xpos, 160, 160, 0, n + 2, ui_extra_enabled ? game_str_sd_wgroup_names[ui_data.sorted.weapon_type[d->api]] : game_str_sd_weaps);
         if (numlines < 18) {
-            listi = uiobj_select_from_list1(xy.x + 14, xy.y + 20, xpos + 131, titlebuf, lineptr, &curweap, flag_tbl_enable, 1, 0x60, false);
+            listi = uiobj_select_from_list3(xy.x + 14, xy.y + 20, xpos + 131, titlebuf, lineptr, &curweap, flag_tbl_enable, 1, 0x60, false, ui_extra_enabled, xy.x, xy.y);
         } else {
-            listi = uiobj_select_from_list2(xy.x + 14, xy.y + 20, xpos + 131, titlebuf, lineptr, &curweap, flag_tbl_enable, 18, 312, 19, ui_data.gfx.design.popscrol_u, 313, 183, ui_data.gfx.design.popscrol_d, 1, 0x60, false);
+            listi = uiobj_select_from_list4(xy.x + 14, xy.y + 20, xpos + 131, titlebuf, lineptr, &curweap, flag_tbl_enable, 18, 312, 19, ui_data.gfx.design.popscrol_u, 313, 183, ui_data.gfx.design.popscrol_d, 1, 0x60, false, ui_extra_enabled, xy.x, xy.y);
         }
-        if (listi < 0) {
+        if (listi == -2) {
+            ui_data.sorted.weapon_type[d->api] = (ui_data.sorted.weapon_type[d->api] + 1) % WEAPON_GROUP_NUM;
+            goto again;
+        } else if (listi < 0) {
             sd->wpnt[wslot] = actwpnt;
             sd->wpnn[wslot] = actwpnn;
         } else {
@@ -965,13 +982,14 @@ static void ui_design_sel_special(struct design_data_s *d, int sslot)
     char titlebuf[0x80];
     char linebuf[SHIP_SPECIAL_NUM * 0x5d];
     const char *lineptr[SHIP_SPECIAL_NUM + 1];
+    struct strbuild_s line_builder = strbuild_init(linebuf, sizeof(linebuf));
     shipdesign_t *sd = &(d->gd->sd);
     ship_special_t actspec = sd->special[sslot];
 
     lbxfont_select(2, 0, 4, 0xe);
 
     {
-        int havelast, bufpos = 0, space, cost;
+        int havelast, space, cost;
         char s1[3] = "\x1dX";
         char s2[3] = "\x1dX";
         char s3[3] = "\x1dX";
@@ -1000,9 +1018,10 @@ static void ui_design_sel_special(struct design_data_s *d, int sslot)
         cost = game_design_calc_cost(d->gd);
         havelast = game_design_build_tbl_fit_special(d->g, d->gd, havebuf, sslot);
 
+        /* game_design_build_tbl_fit_special ensures that havelast < SHIP_SPECIAL_NUM. */
         for (int i = 0; i <= havelast; ++i) {
             if (havebuf[i] >= 0) {
-                int space2, cost2, power, sizei, len;
+                int space2, cost2, power, sizei;
                 ++numlines;
                 sd->special[sslot] = i;
                 game_design_update_engines(sd);
@@ -1015,16 +1034,13 @@ static void ui_design_sel_special(struct design_data_s *d, int sslot)
                 power = tbl_shiptech_special[i].power[sd->hull];
                 cost2 = game_design_calc_cost(d->gd) - cost;
                 sizei = game_design_calc_space_item(d->gd, DESIGN_SLOT_SPECIAL1, i);
-                lineptr[n] = &linebuf[bufpos];
-                len = sprintf(&linebuf[bufpos], "%s%s%s%s", *tbl_shiptech_special[i].nameptr, s1, *tbl_shiptech_special[i].extratextptr, s2);
-                bufpos += len;
-                len = sprintf(&linebuf[bufpos], "%i%s%i%s    %i%s           %i", cost2, s3, sizei, s4, power, s5, space2);
-                bufpos += len + 1;
-                ++n;
+                strbuild_catf(&line_builder, "%s%s%s%s", *tbl_shiptech_special[i].nameptr, s1, *tbl_shiptech_special[i].extratextptr, s2);
+                strbuild_catf(&line_builder, "%i%s%i%s    %i%s           %i", cost2, s3, sizei, s4, power, s5, space2);
+                lineptr[n++] = strbuild_finish(&line_builder);
             }
         }
-        lineptr[n] = 0;
-        sprintf(titlebuf, "%s%s%s%s%s%s%s%s    %s%s           %s", game_str_sd_specname, s1, game_str_sd_descr, s2, game_str_sd_cost, s3, game_str_sd_size, s4, game_str_sd_power, s5, game_str_sd_space);
+        lineptr[n] = NULL;
+        lib_sprintf(titlebuf, sizeof(titlebuf), "%s%s%s%s%s%s%s%s    %s%s           %s", game_str_sd_specname, s1, game_str_sd_descr, s2, game_str_sd_cost, s3, game_str_sd_size, s4, game_str_sd_power, s5, game_str_sd_space);
     }
     {
         int listi;
@@ -1054,6 +1070,9 @@ static void ui_design_sub(struct ui_design_data_s *u, design_slot_t selmode)
 {
     struct design_data_s *d = u->d;
     uiobj_unset_callback();
+    if (ui_extra_enabled) {
+        hw_video_copy_back_to_page3();
+    }
     uiobj_set_callback_and_delay(design_draw_sub_cb, 0, 1);
     switch (selmode) {
         case DESIGN_SLOT_COMP:
@@ -1097,6 +1116,29 @@ static void ui_design_sub(struct ui_design_data_s *u, design_slot_t selmode)
     uiobj_set_help_id(5);
 }
 
+bool ui_design_try_inc_weap_count(struct game_s *g, struct design_data_s *d, int i, int inc)
+{
+    struct game_design_s *gd = d->gd;
+    shipdesign_t *sd = &(gd->sd);
+    bool ret = false;
+    int space;
+    if (sd->wpnn[i] + inc > 99) {
+        inc = 99 - sd->wpnn[i];
+    }
+    sd->wpnn[i] += inc;
+    game_design_update_engines(sd);
+    space = game_design_calc_space(gd);
+    if (space >= 0) {
+        sd->space = space;
+        game_design_update_haveflags(d);
+        ret = true;
+    } else {
+        sd->wpnn[i] -= inc;
+        game_design_update_engines(sd);
+    }
+    return ret;
+}
+
 /* -------------------------------------------------------------------------- */
 
 bool ui_design(struct game_s *g, struct game_design_s *gd, player_id_t active_player)
@@ -1131,14 +1173,14 @@ bool ui_design(struct game_s *g, struct game_design_s *gd, player_id_t active_pl
         oi = uiobj_handle_input_cond();
         if (oi == u.oi_name) {
             ui_sound_play_sfx_24();
-            util_trim_whitespace(sd->name);
+            util_trim_whitespace(sd->name, SHIP_NAME_LEN);
             if (sd->name[0] == '\0') {
-                strcpy(sd->name, gd->names[sd->hull]);
+                lib_strcpy(sd->name, gd->names[sd->hull], SHIP_NAME_LEN);
             }
             flag_name = true;
         }
         if (!flag_name) {
-            strcpy(sd->name, gd->names[sd->hull]);
+            lib_strcpy(sd->name, gd->names[sd->hull], SHIP_NAME_LEN);
         }
         if ((oi == u.oi_cancel) || (oi == UIOBJI_ESC)) {
             ui_sound_play_sfx_06();
@@ -1165,17 +1207,18 @@ bool ui_design(struct game_s *g, struct game_design_s *gd, player_id_t active_pl
               && (sd->wpnn[i] < 99)
               && ((oi == u.oi_tbl_weap_up[i]) || ((oi == u.oi_tbl_weap_n_scroll[i]) && ((u.scroll > 0) != ui_mwi_counter)))
             ) {
-                int space;
                 ui_sound_play_sfx_24();
-                ++sd->wpnn[i];
-                game_design_update_engines(sd);
-                space = game_design_calc_space(gd);
-                if (space >= 0) {
-                    sd->space = space;
-                    game_design_update_haveflags(&d);
+                if (kbd_is_modifier(MOO_MOD_ALT)) {
+                    if (!ui_design_try_inc_weap_count(g, &d, i, 99)) {
+                        while (ui_design_try_inc_weap_count(g, &d, i, 10)) {}
+                        while (ui_design_try_inc_weap_count(g, &d, i, 1)) {}
+                    }
+                } else if (kbd_is_modifier(MOO_MOD_CTRL)) {
+                    if (!ui_design_try_inc_weap_count(g, &d, i, 10)) {
+                        while (ui_design_try_inc_weap_count(g, &d, i, 1)) {}
+                    }
                 } else {
-                    --sd->wpnn[i];
-                    game_design_update_engines(sd);
+                    ui_design_try_inc_weap_count(g, &d, i, 1);
                 }
                 break;
             } else if (1
@@ -1183,7 +1226,17 @@ bool ui_design(struct game_s *g, struct game_design_s *gd, player_id_t active_pl
               && ((oi == u.oi_tbl_weap_dn[i]) || ((oi == u.oi_tbl_weap_n_scroll[i]) && ((u.scroll < 0) != ui_mwi_counter)))
             ) {
                 ui_sound_play_sfx_24();
-                --sd->wpnn[i];
+                if (kbd_is_modifier(MOO_MOD_CTRL)) {
+                    if (sd->wpnn[i] < 10) {
+                        sd->wpnn[i] = 0;
+                    } else {
+                        sd->wpnn[i] -= 10;
+                    }
+                } else if (kbd_is_modifier(MOO_MOD_ALT)) {
+                    sd->wpnn[i] = 0;
+                } else {
+                    --sd->wpnn[i];
+                }
                 game_design_update_haveflags(&d);
                 d.flag_tbl_weap_dn[i] = (sd->wpnn[i] == 0);
                 break;
