@@ -9,6 +9,7 @@
 #include "game_str.h"
 #include "hw.h"
 #include "kbd.h"
+#include "mouse.h"
 #include "lbx.h"
 #include "lbxfont.h"
 #include "lbxgfx.h"
@@ -24,6 +25,7 @@
 #include "uiobj.h"
 #include "uipal.h"
 #include "uisound.h"
+#include "uistarmap.h"
 #include "uistarmap_common.h"
 #include "uiswitch.h"
 
@@ -135,6 +137,16 @@ static void gmap_draw_cb(void *vptr)
         }
     }
 
+    if (ui_extra_enabled) {
+        char buf[32];
+        lib_sprintf(buf, sizeof(buf), "Year %i", g->year+2299);
+        lbxfont_select(0, 6, 0, 0);
+        lbxfont_set_color_c_n(0, 5);
+        lbxfont_print_str_normal(9, 9, buf, UI_SCREEN_W, ui_scale);
+        lbxfont_set_color_c_n(194, 5);
+        lbxfont_print_str_normal(8, 8, buf, UI_SCREEN_W, ui_scale);
+    }
+
     for (int i = 0; i < g->galaxy_stars; ++i) {
         const planet_t *p = &(g->planet[i]);
         if (BOOLVEC_IS1(p->within_srange, d->api)) {
@@ -278,7 +290,7 @@ static void gmap_draw_cb(void *vptr)
             lbxfont_print_str_normal(240, 119, game_str_tbl_sm_pspecial[4], UI_SCREEN_W, ui_scale);
             lbxfont_print_str_normal(240, 127, game_str_tbl_sm_pspecial[5], UI_SCREEN_W, ui_scale);
             lbxfont_select_set_12_1(2, 0xe, 0, 0);
-            lbxfont_print_str_normal(240, 135, game_str_tbl_sm_pspecial[1], UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_normal(240, 135, game_str_tbl_sm_pspecial[3], UI_SCREEN_W, ui_scale);
             lbxfont_print_str_normal(240, 143, game_str_tbl_gm_spec[6], UI_SCREEN_W, ui_scale);
             lbxfont_select(2, 6, 0, 0);
             lbxfont_print_str_normal(295, 103, game_str_gm_prod, UI_SCREEN_W, ui_scale);
@@ -287,15 +299,15 @@ static void gmap_draw_cb(void *vptr)
             lbxfont_print_str_normal(295, 127, game_str_gm_prod, UI_SCREEN_W, ui_scale);
             lbxfont_print_str_normal(295, 135, game_str_gm_tech, UI_SCREEN_W, ui_scale);
             lbxfont_print_str_normal(295, 143, game_str_gm_tech, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(295, 103, game_str_gm_1_3, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(295, 111, game_str_gm_1_2, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(295, 119, game_str_gm_2x, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(295, 127, game_str_gm_3x, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(295, 135, game_str_gm_2x, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_right(295, 143, game_str_gm_4x, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_center(272, 152, game_str_gm_prodb1, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_center(272, 159, game_str_gm_prodb2, UI_SCREEN_W, ui_scale);
-            lbxfont_print_str_center(272, 166, game_str_gm_prodb3, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 103, game_str_gm_1_3, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 111, game_str_gm_1_2, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 119, game_str_gm_2x, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 127, game_str_gm_3x, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 135, game_str_gm_2x, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_right(291, 143, game_str_gm_4x, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_center(275, 152, game_str_gm_prodb1, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_center(275, 159, game_str_gm_prodb2, UI_SCREEN_W, ui_scale);
+            lbxfont_print_str_center(275, 166, game_str_gm_prodb3, UI_SCREEN_W, ui_scale);
             break;
         default:
             break;
@@ -304,19 +316,17 @@ static void gmap_draw_cb(void *vptr)
     lbxfont_set_temp_color(0x2b);
     lbxfont_select_set_12_4(4, 0xf, 0, 0);
     lbxfont_print_str_normal(242, 8, game_str_gm_gmap, UI_SCREEN_W, ui_scale);
-    if (ui_extra_enabled) {
-        lbxfont_print_num_normal(250, 88, g->year + YEAR_BASE, UI_SCREEN_W, ui_scale);
-    } else {
-        lbxfont_print_str_normal(250, 88, game_str_gm_mapkey, UI_SCREEN_W, ui_scale);
-    }
+    lbxfont_print_str_normal(250, 88, game_str_gm_mapkey, UI_SCREEN_W, ui_scale);
     lbxfont_set_temp_color(0x00);
     gmap_blink_step(&(d->b));
-    if (ui_extra_enabled) {
+    if (ui_scale > 1) {
         const uint8_t ctblf[5] = { 0xbd, 0xbc, 0xbb, 0xba, 0xb9 };
         const uint8_t ctblb[5] = { 0xba, 0xbb, 0xbc, 0xbd, 0xb9 };
         int x0, y0, x1, y1, pos;
         x0 = (ui_data.starmap.x * 224) / g->galaxy_maxx + 7;
+        SETMAX(x0, 7);
         y0 = (ui_data.starmap.y * 185) / g->galaxy_maxy + 7;
+        SETMAX(y0, 7);
         x1 = ((ui_data.starmap.x + ((108 * ui_scale) / starmap_scale)) * 224) / g->galaxy_maxx + 7;
         SETMIN(x1, 230);
         y1 = ((ui_data.starmap.y + ((86 * ui_scale) / starmap_scale)) * 185) / g->galaxy_maxy + 7;
@@ -334,7 +344,11 @@ static void gmap_draw_cb(void *vptr)
         int x, y;
         x = (ui_data.starmap.x * 224) / g->galaxy_maxx + 7;
         y = (ui_data.starmap.y * 185) / g->galaxy_maxy + 7;
-        lbxgfx_draw_frame(x, y, ui_data.gfx.starmap.bmap, UI_SCREEN_W, ui_scale);
+        if (ui_sm_expanded_scroll) {
+            lbxgfx_draw_frame_offs(x, y, ui_data.gfx.starmap.bmap, GMAP_LIMITS, UI_SCREEN_W, ui_scale);
+        } else {
+            lbxgfx_draw_frame(x, y, ui_data.gfx.starmap.bmap, UI_SCREEN_W, ui_scale);
+        }
     }
 }
 
@@ -373,6 +387,7 @@ bool ui_gmap(struct game_s *g, player_id_t active_player)
     struct gmap_data_s d;
     bool flag_done = false, flag_do_focus = false;
     int16_t /*oi_col, oi_env, oi_min,*/ oi_ok, oi_tbl_planet[PLANETS_MAX];
+    int16_t oi_map = UIOBJI_INVALID;
 
     gmap_load_data(&d);
     d.g = g;
@@ -396,6 +411,9 @@ bool ui_gmap(struct game_s *g, player_id_t active_player)
         /* FIXME limits not set! ... but no need to limit anyway */
         oi_tbl_planet[i] = uiobj_add_mousearea/*_limited*/(x, y, x + 4, y + 4, MOO_KEY_UNKNOWN);
     }
+    if (ui_extra_enabled) {
+        oi_map = uiobj_add_mousearea(GMAP_LIMITS, MOO_KEY_UNKNOWN);
+    }
 
     uiobj_set_help_id(9);
     uiobj_set_callback_and_delay(gmap_draw_cb, &d, 4);
@@ -419,6 +437,13 @@ bool ui_gmap(struct game_s *g, player_id_t active_player)
                 break;
             }
         }
+        if (ui_extra_enabled && (oi == oi_map)) {
+            int x, y;
+            x = ((moouse_x / ui_scale - 7) * g->galaxy_maxx) / 224;
+            y = ((moouse_y / ui_scale - 7) * g->galaxy_maxy) / 185;
+            ui_starmap_set_pos(g, x, y);
+            flag_done = true;
+        }
         if (!flag_done) {
             gmap_draw_cb(&d);
             ui_draw_finish();
