@@ -95,7 +95,7 @@ void ui_landing_free_data(struct landing_data_s *d)
     lbxfile_item_release(LBXFILE_LANDING, d->gfx_walk);
 }
 
-void ui_landing(struct game_s *g, player_id_t pi, uint8_t planet_i)
+void ui_landing(struct game_s *g, int pi, uint8_t planet_i)
 {
     struct landing_data_s d;
     bool flag_done = false;
