@@ -192,7 +192,7 @@ static bool ui_new_game_pname(struct game_new_options_s *newopts, struct new_gam
     bool flag_ok;
 
     if (!flag_generate) {
-        strcpy(buf, newopts->pdata[d->pi].playername);
+        lib_strcpy(buf, newopts->pdata[d->pi].playername, sizeof(buf));
         flag_generate = (buf[0] == '\0');
     }
     uiobj_set_callback_and_delay(new_game_draw_banner_cb, d, 2);
@@ -202,16 +202,16 @@ static bool ui_new_game_pname(struct game_new_options_s *newopts, struct new_gam
     while (!flag_ok) {
         lbxfont_select(5, 0xf, 0xf, 0xf);
         if (flag_generate) {
-            game_new_generate_emperor_name(d->newopts->pdata[d->pi].race, buf);
+            game_new_generate_emperor_name(d->newopts->pdata[d->pi].race, buf, sizeof(buf));
         }
         if (!uiobj_read_str(0xf, 0x16, 0x41, buf, 0xb/*len*/, 0, 0, tbl_cursor_color)) {
             return false;
         }
-        util_trim_whitespace(buf);
+        util_trim_whitespace(buf, sizeof(buf));
         flag_ok = buf[0] != '\0';
         flag_generate = true;
     }
-    strcpy(newopts->pdata[d->pi].playername, buf);
+    lib_strcpy(newopts->pdata[d->pi].playername, buf, EMPEROR_NAME_LEN);
     ui_sound_play_sfx_24();
     return true;
 }
@@ -222,7 +222,7 @@ static bool ui_new_game_hname(struct game_new_options_s *newopts, struct new_gam
     bool flag_ok;
 
     if (!flag_generate) {
-        strcpy(buf, newopts->pdata[d->pi].homename);
+        lib_strcpy(buf, newopts->pdata[d->pi].homename, sizeof(buf));
         flag_generate = (buf[0] == '\0');
     }
     uiobj_set_callback_and_delay(new_game_draw_banner_cb, d, 2);
@@ -232,16 +232,16 @@ static bool ui_new_game_hname(struct game_new_options_s *newopts, struct new_gam
     while (!flag_ok) {
         lbxfont_select(5, 0xf, 0xf, 0xf);
         if (flag_generate) {
-            game_new_generate_home_name(d->newopts->pdata[d->pi].race, buf);
+            game_new_generate_home_name(d->newopts->pdata[d->pi].race, buf, sizeof(buf));
         }
         if (!uiobj_read_str(0xf, 0x16, 0x32, buf, PLANET_NAME_LEN, 0, 0, tbl_cursor_color)) {
             return false;
         }
-        util_trim_whitespace(buf);
+        util_trim_whitespace(buf, sizeof(buf));
         flag_ok = buf[0] != '\0';
         flag_generate = true;
     }
-    strcpy(newopts->pdata[d->pi].homename, buf);
+    lib_strcpy(newopts->pdata[d->pi].homename, buf, PLANET_NAME_LEN);
     ui_sound_play_sfx_24();
 
     lbxfont_select(5, 1, 0xf, 0xf);
@@ -298,7 +298,6 @@ static void new_game_draw_extra_cb(void *vptr)
     if (!d->have_human) {
         lbxfont_print_str_center(160, 2, game_str_ng_allai, UI_SCREEN_W, ui_scale);
     }
-    lbxfont_print_str_normal(103, 165, game_ais[d->newopts->ai_id]->name, UI_SCREEN_W, ui_scale);
     if (++d->frame >= 10) {
         d->frame = 0;
     }
@@ -307,16 +306,28 @@ static void new_game_draw_extra_cb(void *vptr)
 static bool ui_new_game_extra(struct game_new_options_s *newopts, struct new_game_data_s *d)
 {
     bool flag_done = false, flag_ok = false;
-    int16_t oi_cancel, oi_ok, oi_ai_id, oi_race[PLAYER_NUM], oi_banner[PLAYER_NUM], oi_pname[PLAYER_NUM], oi_hname[PLAYER_NUM], oi_ai[PLAYER_NUM];
+    int16_t oi_cancel, oi_ok, oi_race[PLAYER_NUM], oi_banner[PLAYER_NUM], oi_pname[PLAYER_NUM], oi_hname[PLAYER_NUM], oi_ai[PLAYER_NUM];
     d->pi = PLAYER_0;
     d->str_title = 0;
     d->frame = 0;
 
-    newopts->pdata[PLAYER_0].race = RACE_HUMAN;
-    newopts->pdata[PLAYER_0].banner = BANNER_BLUE;
-    d->have_human = true;
-    game_new_generate_emperor_name(newopts->pdata[PLAYER_0].race, newopts->pdata[PLAYER_0].playername);
-    game_new_generate_home_name(newopts->pdata[PLAYER_0].race, newopts->pdata[PLAYER_0].homename);
+    d->have_human = false;
+    for (int i = 0; i < newopts->players; ++i) {
+        if (!newopts->pdata[i].is_ai) {
+            d->have_human = true;
+            break;
+        }
+    }
+    for (int i = 0; i < newopts->players; ++i) {
+        if (newopts->pdata[i].race != RACE_RANDOM) {
+            if (!strlen(newopts->pdata[i].playername)) {
+                game_new_generate_emperor_name(newopts->pdata[i].race, newopts->pdata[i].playername, EMPEROR_NAME_LEN);
+            }
+            if (!strlen(newopts->pdata[i].homename)) {
+                game_new_generate_home_name(newopts->pdata[i].race, newopts->pdata[i].homename, PLANET_NAME_LEN);
+            }
+        }
+    }
     uiobj_table_clear();
     ui_palette_fadeout_19_19_1();
     d->fadein = true;
@@ -336,8 +347,6 @@ static bool ui_new_game_extra(struct game_new_options_s *newopts, struct new_gam
         ui_draw_box1(x0 + 43, y0, x0 + 43 + 41, y0 + 35, 0x9b, 0x9b, ui_scale);
     }
     lbxfont_select(5, 0, 0, 0);
-    lbxfont_print_str_right(100 - 3, 165, game_str_ng_ai, UI_SCREEN_W, ui_scale);
-    lbxfont_print_str_normal(100, 165, ":", UI_SCREEN_W, ui_scale);
     lbxfont_print_str_center(40, 180, game_str_ng_cancel, UI_SCREEN_W, ui_scale);
     lbxfont_print_str_center(260, 180, game_str_ng_ok, UI_SCREEN_W, ui_scale);
 
@@ -348,7 +357,6 @@ static bool ui_new_game_extra(struct game_new_options_s *newopts, struct new_gam
         uiobj_table_clear(); \
         oi_cancel = uiobj_add_mousearea(0, 170, 80, 199, MOO_KEY_ESCAPE); \
         oi_ok = uiobj_add_mousearea(220, 170, 300, 199, MOO_KEY_SPACE); \
-        oi_ai_id = uiobj_add_mousearea(100 - 3, 165, 150, 177, MOO_KEY_a); \
         for (int i = 0; i < newopts->players; ++i) { \
             int x0 = 4 + (i / 3) * 160; \
             int y0 = 20 + (i % 3) * 50; \
@@ -388,8 +396,6 @@ static bool ui_new_game_extra(struct game_new_options_s *newopts, struct new_gam
                 flag_ok = true;
                 flag_done = true;
             }
-        } else if (oi == oi_ai_id) {
-            d->newopts->ai_id = (d->newopts->ai_id + 1) % GAME_AI_NUM;
         }
         for (int i = 0; i < newopts->players; ++i) {
             if (oi == oi_race[i]) {
@@ -400,8 +406,8 @@ static bool ui_new_game_extra(struct game_new_options_s *newopts, struct new_gam
                 new_race = newopts->pdata[i].race;
                 if (new_race != old_race) {
                     if (new_race < RACE_NUM) {
-                        game_new_generate_emperor_name(new_race, newopts->pdata[i].playername);
-                        game_new_generate_home_name(new_race, newopts->pdata[i].homename);
+                        game_new_generate_emperor_name(new_race, newopts->pdata[i].playername, EMPEROR_NAME_LEN);
+                        game_new_generate_home_name(new_race, newopts->pdata[i].homename, PLANET_NAME_LEN);
                     } else {
                         newopts->pdata[i].playername[0] = '\0';
                         newopts->pdata[i].homename[0] = '\0';
@@ -544,21 +550,63 @@ bool ui_new_game(struct game_new_options_s *newopts)
     uiobj_unset_callback();
 
     if (flag_ok) {
-        if (ui_extra_enabled) {
-            flag_ok = ui_new_game_extra(newopts, &d);
-        } else {
-            flag_ok = ui_new_game_racebannernames(newopts, &d);
-        }
+        flag_ok = ui_new_game_racebannernames(newopts, &d);
     }
 
     uiobj_unset_callback();
     new_game_free_data(&d);
 
-    ui_palette_fadeout_19_19_1();
-    ui_draw_erase_buf();
-    hw_video_draw_buf();
-    ui_draw_erase_buf();
-    hw_video_draw_buf();
+    return flag_ok;
+}
+
+bool ui_custom_game(struct game_new_options_s *newopts) {
+    struct new_game_data_s d;
+    bool flag_ok = false;
+
+    d.newopts = newopts;
+
+    new_game_load_data(&d);
+
+    flag_ok = ui_new_game_extra(newopts, &d);
+
+    new_game_free_data(&d);
+    return flag_ok;
+}
+
+bool ui_challenge_game(struct game_new_options_s *newopts) {
+    static const struct game_new_options_s challenge = GAME_NEW_OPTS_CHALLENGE_118835000;
+    struct new_game_data_s d;
+    bool flag_ok = false;
+
+    d.newopts = newopts;
+    *d.newopts = challenge;
+
+    new_game_load_data(&d);
+
+    flag_ok = ui_new_game_racebannernames(newopts, &d);
+
+    uiobj_unset_callback();
+    new_game_free_data(&d);
+
+    if (d.newopts->pdata[0].race == RACE_MRRSHAN) {
+        d.newopts->pdata[1].race = RACE_ALKARI;
+    }
+
+    if (d.newopts->pdata[0].race == RACE_SAKKRA) {
+        d.newopts->pdata[2].race = RACE_MEKLAR;
+    }
+
+    if (d.newopts->pdata[0].race == RACE_PSILON) {
+        d.newopts->pdata[3].race = RACE_HUMAN;
+    }
+
+    if (d.newopts->pdata[0].race == RACE_KLACKON) {
+        d.newopts->pdata[4].race = RACE_MEKLAR;
+    }
+
+    if (d.newopts->pdata[0].race == RACE_SILICOID) {
+        d.newopts->pdata[5].race = RACE_HUMAN;
+    }
 
     return flag_ok;
 }
