@@ -153,67 +153,6 @@ int uiobj_maxy = 0;
 
 /* -------------------------------------------------------------------------- */
 
-#ifdef FEATURE_MODEBUG
-#define DEBUGLEVEL_UIOBJ    1
-static void dump_uiobj_p(const uiobj_t *p)
-{
-    LOG_DEBUG((DEBUGLEVEL_UIOBJ, "i:%i xy:%i-%i,%i-%i s:%i t:%x key:%05x(%c) vptr:%i*:%i ", (p - uiobj_tbl), p->x0, p->x1, p->y0, p->y1, p->scale, p->type, p->key, (p->key >= 0x20 && p->key < 0x7e) ? p->key : '.', p->vptr ? 0 : 1, p->vptr ? *p->vptr : 0));
-    switch (p->type) {
-        case UIOBJ_TYPE_BUTTON:
-        case UIOBJ_TYPE_TOGGLE:
-        case UIOBJ_TYPE_SET:
-        case UIOBJ_TYPE_SETVAL:
-            LOG_DEBUG((DEBUGLEVEL_UIOBJ, "font:%i,%x '%s' n0:%i lbx:%p\n", p->t0.fontnum, p->t0.fonta2, p->t0.str, p->t0.indep, p->t0.lbxdata));
-            break;
-        case UIOBJ_TYPE_TEXTINPUT:
-            LOG_DEBUG((DEBUGLEVEL_UIOBJ, "font:%i,%x,%x '%s' rc:%02x ar:%i al:%i len:%i z22:%i\n", p->t4.fontnum, p->t4.fonta2, p->t4.fonta4, p->t4.buf, p->t4.rectcolor, p->t4.align_right, p->t4.allow_lcase, p->t4.max_chars, p->t4.colortbl != 0));
-            break;
-        default:
-            LOG_DEBUG((DEBUGLEVEL_UIOBJ, "?\n"));
-            break;
-        case UIOBJ_TYPE_SLIDER:
-            LOG_DEBUG((DEBUGLEVEL_UIOBJ, "p:%p cb:%p ctx:%p v:%i-%i si:%i\n", p->vptr, p->t6.cb, p->t6.ctx, p->t6.vmin, p->t6.vmax, p->t6.slideri));
-            break;
-        case UIOBJ_TYPE_MOUSEAREA:
-            LOG_DEBUG((DEBUGLEVEL_UIOBJ, "\n"));
-            break;
-        case UIOBJ_TYPE_ALTSTR:
-            LOG_DEBUG((DEBUGLEVEL_UIOBJ, "'%s' p:%i l:%i\n", p->t8.str, p->t8.pos, p->t8.len));
-            break;
-        case UIOBJ_TYPE_TEXTLINE:
-            LOG_DEBUG((DEBUGLEVEL_UIOBJ, "font:%i,%i|%i s:%i z12:%i '%s' z18:%i p0v:%i\n", p->ta.fontnum, p->ta.fonta2, p->ta.fonta2b, p->ta.subtype, p->ta.z12, p->ta.str, p->ta.z18, p->ta.sp0v));
-            break;
-        case UIOBJ_TYPE_SCROLLAREA:
-            LOG_DEBUG((DEBUGLEVEL_UIOBJ, "xd:%i yd%i xp:%p yp:%p\n", p->tb.xdiv, p->tb.ydiv, p->tb.xptr, p->tb.yptr));
-            break;
-    }
-}
-#define DUMP_UIOBJ_P(x) dump_uiobj_p x
-#else
-#define DUMP_UIOBJ_P(x)
-#endif
-
-/* -------------------------------------------------------------------------- */
-
-#ifdef FEATURE_MODEBUG
-static int16_t uiobj_alloc(void)
-{
-    static int nmax = 150; /* MOO1 max */
-    int num = uiobj_table_num;
-    if (num > nmax) {
-        nmax = num;
-        LOG_DEBUG((DEBUGLEVEL_UIOBJ, "uiobj tbl use %i/%i\n", num, UIOBJ_MAX));
-    }
-    if (num < (UIOBJ_MAX - 1)) {
-        ++uiobj_table_num;
-    } else {
-        LOG_DEBUG((DEBUGLEVEL_UIOBJ, "BUG: hit uiobj tbl max %i: ", UIOBJ_MAX));
-        DUMP_UIOBJ_P((&(uiobj_tbl[num])));
-        log_fatal_and_die("uiobj_table size exceeded");
-    }
-    return num;
-}
-#else
 static int16_t uiobj_alloc(void)
 {
     if (uiobj_table_num < (UIOBJ_MAX - 1)) {
@@ -222,7 +161,6 @@ static int16_t uiobj_alloc(void)
         log_fatal_and_die("uiobj_table size exceeded");
     }
 }
-#endif
 
 static int smidx(const uiobj_t *p)
 {
@@ -277,7 +215,6 @@ static inline bool uiobj_is_at_xy(const uiobj_t *p, int x, int y)
 
 static void uiobj_handle_t03_cond(uiobj_t *p, bool cond)
 {
-    /* p->type: UIOBJ_TYPE_BUTTON, UIOBJ_TYPE_TOGGLE, UIOBJ_TYPE_SET, UIOBJ_TYPE_SETVAL */
     if (cond) {
         lbxgfx_set_frame_0(p->t0.lbxdata);
         lbxgfx_draw_frame(p->x0, p->y0, p->t0.lbxdata, UI_SCREEN_W, p->scale);
@@ -298,7 +235,6 @@ static void uiobj_handle_t03_cond(uiobj_t *p, bool cond)
 
 static void uiobj_handle_t4_sub2(uiobj_t *p, uint16_t len, uint16_t a4, const char *str)
 {
-    /* p->type == UIOBJ_TYPE_TEXTINPUT */
     char strbuf[64];
     int16_t si, va;
     si = a4;
@@ -524,7 +460,6 @@ static void uiobj_handle_t4_sub1(uiobj_t *p)
 
 static void uiobj_handle_t6_slider_input(uiobj_t *p)
 {
-    /* p->type == UIOBJ_TYPE_SLIDER */
     int16_t sliderval, slideroff, di;
     di = moouse_x + uiobj_mouseoff;
     slideroff = ((p->t6.vmax - p->t6.vmin) * (di - p->x0 * p->scale)) / ((p->x1 - p->x0) * p->scale);
@@ -545,7 +480,6 @@ static void uiobj_handle_t6_slider_input(uiobj_t *p)
 
 static void uiobj_handle_ta_sub1(int x0, int y0, int x1, int y1, uint8_t subtype, uint8_t p0v, int scale)
 {
-    /* type == UIOBJ_TYPE_TEXTLINE */
     switch (subtype) {
         case 1:
             ui_draw_filled_rect(x0, y0, x1, y1, p0v, scale);
@@ -842,7 +776,6 @@ static inline bool uiobj_kbd_dir_obj_ok(const uiobj_t *p)
 
 static int16_t uiobj_kbd_dir_key_dxdy(int dirx, int diry, int16_t oi2, int mx, int my)
 {
-    /* FIXME this behaves like MOO1, meaning it sucks */
     int dx = UIOBJ_OFFSCREEN, dy = UIOBJ_OFFSCREEN;
     int slope = UIOBJ_OFFSCREEN;
     int mind = UIOBJ_OFFSCREEN * UIOBJ_OFFSCREEN;
@@ -1015,12 +948,12 @@ static int16_t uiobj_kbd_dir_key_dxdy(int dirx, int diry, int16_t oi2, int mx, i
                     slope = UIOBJ_OFFSCREEN;
                     continue;
                 }
-                if ((dx < dy) && (dy != 0)) {
-                    slope = (dx * 100) / dy;
-                }
-                if ((dy <= dx) && (dx != 0)) {
+                if ((dx >= dy) && (dy != 0)) {
                     slope = (dy * 100) / dx;
                 }
+                if ((dy > dx) && (dx != 0)) {
+                    slope = (dx * 100) / dy;
+                }
                 if ((dx == 0) || (dy == 0)) {
                     slope = UIOBJ_OFFSCREEN;
                 }
@@ -1626,15 +1559,6 @@ static void uiobj_add_set_xys(uiobj_t *p, uint16_t x0, uint16_t y0, uint16_t x1,
     p->y1 = y1;
 }
 
-static void uiobj_add_set_xys_offscreen(uiobj_t *p)
-{
-    p->scale = 1;
-    p->x0 = UIOBJ_OFFSCREEN;
-    p->y0 = UIOBJ_OFFSCREEN;
-    p->x1 = UIOBJ_OFFSCREEN;
-    p->y1 = UIOBJ_OFFSCREEN;
-}
-
 static void uiobj_add_t03_do(uint16_t x, uint16_t y, const char *str, uint8_t *lbxdata, mookey_t key, uint8_t scale)
 {
     uiobj_t *p = &uiobj_tbl[uiobj_table_num];
@@ -1985,7 +1909,11 @@ int16_t uiobj_add_mousearea_all(mookey_t key)
 int16_t uiobj_add_inputkey(uint32_t key)
 {
     uiobj_t *p = &uiobj_tbl[uiobj_table_num];
-    uiobj_add_set_xys_offscreen(p);
+    p->x0 = UIOBJ_OFFSCREEN;
+    p->y0 = UIOBJ_OFFSCREEN;
+    p->x1 = UIOBJ_OFFSCREEN;
+    p->y1 = UIOBJ_OFFSCREEN;
+    p->scale = 1;
     p->type = UIOBJ_TYPE_MOUSEAREA;
     p->vptr = 0;
     p->key = key;
@@ -1995,13 +1923,20 @@ int16_t uiobj_add_inputkey(uint32_t key)
 int16_t uiobj_add_alt_str(const char *str)
 {
     uiobj_t *p = &uiobj_tbl[uiobj_table_num];
-    int len = strlen(str);
-    uiobj_add_set_xys_offscreen(p);
+    int len = 0;
+    while ((str[len] != 0) && (len < 0x1e)) {
+        ++len;
+    }
+    p->x0 = UIOBJ_OFFSCREEN;
+    p->y0 = UIOBJ_OFFSCREEN;
+    p->x1 = UIOBJ_OFFSCREEN;
+    p->y1 = UIOBJ_OFFSCREEN;
+    p->scale = 1;
     p->type = UIOBJ_TYPE_ALTSTR;
     p->vptr = 0;
     p->t8.str = str;
     p->t8.pos = 0;
-    p->t8.len = MIN(len, 0x1e);
+    p->t8.len = len;
     {
         char b = *str;
         if ((b >= 'a') && (b <= 'z')) {
@@ -2239,7 +2174,7 @@ int16_t uiobj_select_from_list4(int x, int y, int w, const char *title, char con
     oi_title = uiobj_add_ta(x, y, w, title, false, &v18, 1, 0, 0, MOO_KEY_UNKNOWN);
 
     upvar = (itemoffs == 0) ? 1 : 0;
-    dnvar = (itemi == itemnum) ? 1 : 0;
+    dnvar = (itemi >= itemnum) ? 1 : 0;
     oi_up = uiobj_add_t2(upx, upy, "", uplbx, &upvar, MOO_KEY_PAGEUP);
     oi_dn = uiobj_add_t2(dnx, dny, "", dnlbx, &dnvar, MOO_KEY_PAGEDOWN);
     if (add_switch) {
@@ -2356,7 +2291,7 @@ int16_t uiobj_select_from_list4(int x, int y, int w, const char *title, char con
             lbxfont_select(lbxfont_get_current_fontnum(), lbxfont_get_current_fonta2(), fonta4, 0);
             oi_title = uiobj_add_ta(x, y, w, title, false, &v18, 1, 0, 0, MOO_KEY_UNKNOWN);
             upvar = (itemoffs == 0) ? 1 : 0;
-            dnvar = (itemi == itemnum) ? 1 : 0;
+            dnvar = (itemi >= itemnum) ? 1 : 0;
             oi_up = uiobj_add_t2(upx, upy, "", uplbx, &upvar, MOO_KEY_PAGEUP);
             oi_dn = uiobj_add_t2(dnx, dny, "", dnlbx, &dnvar, MOO_KEY_PAGEDOWN);
             if (add_switch) {
