@@ -187,7 +187,7 @@ static void races_draw_cb(void *vptr)
             lbxfont_print_str_normal(x + 60, y + 9, str, UI_SCREEN_W, ui_scale);
         }
         if (e->trade_bc[pi] != 0) {
-            lib_sprintf(buf, sizeof(buf), "%s: %i %s/%s", game_str_ra_trade, e->trade_bc[pi], game_str_bc, game_str_year);
+            lib_sprintf(buf, sizeof(buf), "%s: %i %s%s", game_str_ra_trade, e->trade_bc[pi], game_str_bc, game_str_year0);
         } else {
             lib_strcpy(buf, game_str_ra_notrade, sizeof(buf));
         }
@@ -308,35 +308,51 @@ int ui_races(struct game_s *g, player_id_t api)
             ui_sound_play_sfx_24();
             d.cursor_mode = 5;
         } else if (oi == oi_sec_minus) {
-            int v;
-            ui_sound_play_sfx_24();
-            v = e->security;
-            v -= 10;
-            SETMAX(v, 0);
-            e->security = v;
+            if (kbd_is_modifier(MOO_MOD_ALT)) {
+                e->security = 0;
+            } else {
+                int v;
+                ui_sound_play_sfx_24();
+                v = e->security;
+                v -= 10;
+                SETMAX(v, 0);
+                e->security = v;
+            }
         } else if (oi == oi_sec_plus) {
-            int v;
-            ui_sound_play_sfx_24();
-            v = e->security;
-            v += 10;
-            SETMIN(v, 200);
-            e->security = v;
+            if (kbd_is_modifier(MOO_MOD_ALT)) {
+                e->security = 200;
+            } else {
+                int v;
+                ui_sound_play_sfx_24();
+                v = e->security;
+                v += 10;
+                SETMIN(v, 200);
+                e->security = v;
+            }
         }
         for (int i = 0; i < (PLAYER_NUM - 1); ++i) {
             if (oi == oi_tbl_spy_minus[i]) {
-                int v;
-                ui_sound_play_sfx_24();
-                v = e->spying[d.tbl_ei[i]];
-                v -= 4;
-                SETMAX(v, 0);
-                e->spying[d.tbl_ei[i]] = v;
+                if (kbd_is_modifier(MOO_MOD_ALT)) {
+                    e->spying[d.tbl_ei[i]] = 0;
+                } else {
+                    int v;
+                    ui_sound_play_sfx_24();
+                    v = e->spying[d.tbl_ei[i]];
+                    v -= 4;
+                    SETMAX(v, 0);
+                    e->spying[d.tbl_ei[i]] = v;
+                }
             } else if (oi == oi_tbl_spy_plus[i]) {
-                int v;
-                ui_sound_play_sfx_24();
-                v = e->spying[d.tbl_ei[i]];
-                v += 4;
-                SETMIN(v, 100);
-                e->spying[d.tbl_ei[i]] = v;
+                if (kbd_is_modifier(MOO_MOD_ALT)) {
+                    e->spying[d.tbl_ei[i]] = 100;
+                } else {
+                    int v;
+                    ui_sound_play_sfx_24();
+                    v = e->spying[d.tbl_ei[i]];
+                    v += 4;
+                    SETMIN(v, 100);
+                    e->spying[d.tbl_ei[i]] = v;
+                }
             } else if (oi == oi_tbl_oppon[i]) {
                 ui_sound_play_sfx_24();
                 if ((d.cursor_mode == 4) || (ui_extra_enabled && (d.cursor_mode == 0))) {
