@@ -31,6 +31,7 @@
 #include "uisearch.h"
 #include "uisound.h"
 #include "uistarmap_common.h"
+#include "util.h"
 
 /* -------------------------------------------------------------------------- */
 
@@ -41,6 +42,9 @@ static void ui_starmap_draw_cb1(void *vptr)
     if (d->g->gaux->flag_cheat_events) {
         ui_draw_text_overlay(0, 0, game_str_no_events);
     }
+    if (d->g->gaux->flag_cheat_elections) {
+        ui_draw_text_overlay(0, 10, game_str_no_elections);
+    }
 }
 
 static void ui_starmap_planet_slider_cb(void *ctx, uint8_t i, int16_t value)
@@ -212,7 +216,7 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
     int16_t oi_b, oi_c, oi_starview1, oi_starview2, oi_shippic, oi_finished, oi_equals, oi_hash,
             oi_f2, oi_f3, oi_f4, oi_f5, oi_f6, oi_f7, oi_f8, oi_f9, oi_f10,
             oi_alt_galaxy, oi_alt_p, oi_alt_events,
-            oi_wheelname, oi_wheelshippic, oi_search,
+            oi_wheelname, oi_wheelshippic, oi_search, oi_rename,
             oi_adj[PLANET_SLIDER_NUM];
     int16_t scrollmisc = 0;
     struct starmap_data_s d;
@@ -241,6 +245,7 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
         oi_hash = UIOBJI_INVALID; \
         oi_wheelname = UIOBJI_INVALID; \
         oi_wheelshippic = UIOBJI_INVALID; \
+        oi_rename = UIOBJI_INVALID; \
         d.sm.oi_ship = UIOBJI_INVALID; \
         d.sm.oi_reloc = UIOBJI_INVALID; \
         d.sm.oi_trans = UIOBJI_INVALID; \
@@ -358,6 +363,7 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
           || ((oi1 == oi_wheelshippic) && (scrollmisc < 0))
         ) {
             int n;
+            ui_sound_play_sfx_24();
             n = p->buildship + 1;
             if (n >= g->eto[active_player].shipdesigns_num) {
                 if (n >= (NUM_SHIPDESIGNS + 1)) {
@@ -400,6 +406,23 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
                         }
                     }
                     flag_done = true;
+                } else if (kbd_is_modifier(MOO_MOD_ALT)) {
+                    lib_strcpy(buf, game_str_adj_set, sizeof(buf));
+                    lib_strcat(buf, game_str_adj_slider[i], sizeof(buf));
+                    lib_strcat(buf, game_str_adj_lock2, sizeof(buf));
+                    lib_strcat(buf, game_str_adj_special[p->special], sizeof(buf));
+                    lib_strcat(buf, game_str_adj_colonies, sizeof(buf));
+                    if (ui_dialog_yesno(g, active_player, buf, 50, 30, 0)) {
+                        bool locked = p->slider_lock[i];
+                        planet_special_t special = p->special;
+                        for (uint8_t pi = 0; pi < g->galaxy_stars; ++pi) {
+                            if ((g->planet[pi].owner == active_player) && g->planet[pi].special == special) {
+                                g->planet[pi].slider_lock[i] = !locked;
+                            }
+                        }
+                    }
+                    flag_done = true;
+
                 } else {
                     p->slider_lock[i] = !p->slider_lock[i];
                     ui_sound_play_sfx_24();
@@ -417,7 +440,7 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
                 } else if (oi1 == d.sm.oi_tbl_slider_plus[i]) {
                     ui_sound_play_sfx_24();
                     if (kbd_is_modifier(MOO_MOD_ALT)) {
-                        game_planet_adjust_percent2(g, g->planet_focus_i[active_player], i, 100);
+                        game_planet_adjust_percent2(g, g->planet_focus_i[active_player], i, 100, true);
                     } else {
                         if (kbd_is_modifier(MOO_MOD_CTRL)) v = p->slider[i] + 1;
                         else v = p->slider[i] + 4;
@@ -566,6 +589,20 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
                 i = 0;
             }
             g->planet_focus_i[active_player] = i;
+        } else if (oi1 == oi_rename) {
+            const uint8_t ctbl[8] = { 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34, 0x34 };
+            char buf[PLANET_NAME_LEN];
+            lib_strcpy(buf, p->name, sizeof(buf));
+            lbxfont_select_set_12_4(4, 0xf, 0, 0);
+            d.planet_draw_name = false;
+            if (uiobj_read_str(239, 10, 65, buf, PLANET_NAME_LEN - 1, 0, false, ctbl)) {
+                util_trim_whitespace(buf, sizeof(buf));
+                if (buf[0] != 0) {
+                    lib_strcpy(p->name, buf, PLANET_NAME_LEN);
+                }
+            }
+            d.planet_draw_name = true;
+            flag_done = true;
         }
         for (int i = 0; i < PLANET_SLIDER_NUM; ++i) {
             if (oi1 == oi_adj[i]) {
@@ -579,7 +616,7 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
                     if (button) {
                         for (uint8_t pi = 0; pi < g->galaxy_stars; ++pi) {
                             if (g->planet[pi].owner == active_player) {
-                                game_planet_adjust_percent2(g, pi, i, game_num_tbl_tech_autoadj[button]);
+                                game_planet_adjust_percent2(g, pi, i, game_num_tbl_tech_autoadj[button], true);
                             }
                         }
                     }
@@ -592,7 +629,7 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
                     if (ui_dialog_yesno(g, active_player, buf, 50, 30, 0)) {
                         for (uint8_t pi = 0; pi < g->galaxy_stars; ++pi) {
                             if (g->planet[pi].owner == active_player) {
-                                game_planet_adjust_percent2(g, pi, i, 100);
+                                game_planet_adjust_percent2(g, pi, i, 100, true);
                             }
                         }
                     }
@@ -608,17 +645,6 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
                 break;
             }
         }
-        d.dist_i = PLANET_NONE;
-        if (!g->evn.build_finished_num[active_player]) {
-            for (int i = 0; i < g->galaxy_stars; ++i) {
-                if (oi2 == d.oi_tbl_stars[i]) {
-                    if (i != g->planet_focus_i[active_player]) {
-                        d.dist_i = i;
-                    }
-                    break;
-                }
-            }
-        }
         p = &(g->planet[g->planet_focus_i[active_player]]);
         ui_starmap_common_update_mouse_hover(&d, oi2);
         if (!flag_done) {
@@ -645,6 +671,7 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
             if (p->owner == active_player) {
                 oi_shippic = uiobj_add_mousearea(228, 139, 275, 175, MOO_KEY_UNKNOWN);
                 oi_wheelshippic = uiobj_add_mousewheel(228, 139, 275, 175, &scrollmisc);
+                oi_rename = uiobj_add_mousearea(227, 8, 310, 20, MOO_KEY_UNKNOWN);
             }
             oi_wheelname = uiobj_add_mousewheel(227, 8, 310, 20, &scrollmisc);
             if (ui_extra_enabled) {
@@ -708,7 +735,6 @@ void ui_starmap_do(struct game_s *g, player_id_t active_player)
             ui_delay_ticks_or_click(STARMAP_DELAY);
         }
     }
-    d.dist_i = PLANET_NONE;
     uiobj_table_clear();
     uiobj_unset_callback();
     uiobj_set_help_id(-1);
