@@ -43,6 +43,13 @@ static void ui_turn_msg_draw_cb(void *vptr)
 
 /* -------------------------------------------------------------------------- */
 
+void ui_turn_pre(const struct game_s *g)
+{
+    struct starmap_data_s d;
+    ui_starmap_draw_button_text(&d, false);
+    hw_video_copy_back_to_page2();
+}
+
 void ui_turn_msg(struct game_s *g, int pi, const char *str)
 {
     struct turnmsg_data_s d;
