@@ -3,6 +3,7 @@
 
 #include "boolvec.h"
 #include "game_types.h"
+#include "ui.h"
 #include "types.h"
 
 #define UI_INPUT_TOKEN_MAX  32
@@ -38,19 +39,21 @@ struct input_token_s {
     } type;
 };
 
+#define BATTLE_SCREEN_HEIGHT (8 * 3)
+#define BATTLE_SCREEN_WIDTH (10 * 4 + 7 + 20)
 struct ui_data_s {
     struct {
         struct input_token_s tok[UI_INPUT_TOKEN_MAX];
         int num;
     } input;
     struct {
-        char screen[8 * 3][10 * 4 + 7 + 20];
+        char screen[BATTLE_SCREEN_HEIGHT][BATTLE_SCREEN_WIDTH];
     } battle;
     struct {
         uint32_t item[PLANETS_MAX + FLEET_ENROUTE_MAX + TRANSPORT_MAX];
     } view;
     BOOLVEC_DECLARE(players_viewing, PLAYER_NUM);
-    char strbuf[1024];
+    char strbuf[UI_STRBUF_SIZE];
 };
 
 extern struct ui_data_s ui_data;
