@@ -5,6 +5,7 @@
 #include "ui.h"
 #include "game.h"
 #include "game_str.h"
+#include "lib.h"
 #include "uiinput.h"
 #include "uiplanet.h"
 #include "uiswitch.h"
@@ -25,7 +26,7 @@ bool ui_explore(struct game_s *g, int pi, uint8_t planet_i, bool by_scanner, boo
     if (flag_colony_ship) {
         char buf[0x80];
         int v;
-        sprintf(buf, "%s %s", game_str_ex_build, game_str_ex_colony);
+        lib_sprintf(buf, sizeof(buf), "%s %s", game_str_ex_build, game_str_ex_colony);
         v = ui_input_list(buf, "> ", il_yes_no);
         flag_colony_ship = (v == 1);
         if (flag_colony_ship) {
@@ -33,7 +34,7 @@ bool ui_explore(struct game_s *g, int pi, uint8_t planet_i, bool by_scanner, boo
             printf("%s %i %s %s%s: (%s) ", game_str_la_inyear, g->year + YEAR_BASE, game_str_la_the, game_str_tbl_race[g->eto[pi].race], game_str_la_formnew, g->planet[planet_i].name);
             name = ui_input_line_len_trim("> ", PLANET_NAME_LEN);
             if (name[0] != '\0') {
-                strcpy(g->planet[planet_i].name, name);
+                lib_strcpy(g->planet[planet_i].name, name, PLANET_NAME_LEN);
             }
         }
     } else {
