@@ -11,6 +11,7 @@
 #include "game_planet.h"
 #include "game_str.h"
 #include "game_tech.h"
+#include "lib.h"
 #include "uidefs.h"
 #include "util.h"
 
@@ -45,7 +46,7 @@ static void ui_planet_print_visible_fleets(const struct game_s *g, player_id_t a
     for (int i = 0; i < g->enroute_num; ++i) {
         const fleet_enroute_t *r = &(g->enroute[i]);
         if (BOOLVEC_IS1(r->visible, api) && (r->dest == planet_i) && ((r->owner == api) || e->have_ia_scanner)) {
-            printf("  - %s fleet ETA %i turns:", game_str_tbl_race[e->race], game_calc_eta(g, r->speed, p->x, p->y, r->x, r->y));
+            printf("  - %s fleet ETA %i turns:", game_str_tbl_race[e->race], game_calc_eta_ship(g, r->speed, p->x, p->y, r->x, r->y));
             for (int i = 0; i < NUM_SHIPDESIGNS; ++i) {
                 printf(" %5i", r->ships[i]);
             }
@@ -61,7 +62,7 @@ static void ui_planet_print_visible_transports(const struct game_s *g, player_id
     for (int i = 0; i < g->transport_num; ++i) {
         const transport_t *r = &(g->transport[i]);
         if (BOOLVEC_IS1(r->visible, api) && (r->dest == planet_i) && ((r->owner == api) || e->have_ia_scanner)) {
-            printf("  - %s transport %i ETA %i turns\n", game_str_tbl_race[e->race], r->pop, game_calc_eta(g, r->speed, p->x, p->y, r->x, r->y));
+            printf("  - %s transport %i ETA %i turns\n", game_str_tbl_race[e->race], r->pop, game_calc_eta_trans(g, r->speed, p->x, p->y, r->x, r->y));
         }
     }
 }
@@ -80,14 +81,10 @@ planet_slider_i_t ui_planet_slider_from_param(struct input_token_s *param)
 
 /* -------------------------------------------------------------------------- */
 
-const char *ui_planet_str(const struct game_s *g, int api, uint8_t planet_i, char *buf)
+const char *ui_planet_str(const struct game_s *g, int api, uint8_t planet_i, char *buf, size_t bufsize)
 {
     const planet_t *p = &(g->planet[planet_i]);
     if (BOOLVEC_IS1(p->explored, api)) {
-        if ((p->owner == api) && (BOOLVEC_IS1(p->extras, PLANET_EXTRAS_GOVERNOR))) {
-            sprintf(buf, "*%s", p->name);
-            return buf;
-        }
         return p->name;
     } else if ((p->owner != PLAYER_NONE) && (0
       || BOOLVEC_IS1(p->within_srange, api)
@@ -96,7 +93,7 @@ const char *ui_planet_str(const struct game_s *g, int api, uint8_t planet_i, cha
     )) {
         return p->name;
     } else {
-        sprintf(buf, "#%c%i", game_str_tbl_sm_stinfo[p->star_type][0]/*HACK*/, planet_i);
+        lib_sprintf(buf, bufsize, "#%c%i", game_str_tbl_sm_stinfo[p->star_type][0]/*HACK*/, planet_i);
         return buf;
     }
 }
@@ -159,7 +156,10 @@ void ui_planet_look(const struct game_s *g, int api, uint8_t planet_i, bool show
     int dist = game_get_min_dist(g, api, planet_i);
     {
         char buf[16];
-        printf("[%i] (%i,%i) %s: ", planet_i, p->x, p->y, ui_planet_str(g, api, planet_i, buf));
+        printf("[%i] (%i,%i) %s: ", planet_i, p->x, p->y, ui_planet_str(g, api, planet_i, buf, sizeof(buf)));
+        if (game_xy_is_in_nebula(g, p->x, p->y)) {
+            printf("(In nebula)\n");
+        }
     }
     if (BOOLVEC_IS1(p->explored, api)) {
         if (p->type == PLANET_TYPE_NOT_HABITABLE) {
@@ -209,15 +209,11 @@ void ui_planet_look(const struct game_s *g, int api, uint8_t planet_i, bool show
                 }
                 printf(". %s %s. Pop %i, bases %i. %s %i %s\n", game_str_tbl_race[g->eto[owner].race], game_str_sm_colony, pop, bases, game_str_sm_range, dist, (dist == 1) ? game_str_sm_parsec : game_str_sm_parsecs);
             } else {
-                printf(", pop %i, bases %i", p->pop, p->missile_bases);
-                if (p->target_bases) {
-                    printf(" (target %i)", p->target_bases);
-                }
-                printf(", factories %i, prod %i (%i), waste %i\n", p->factories, p->prod_after_maint, p->total_prod, p->waste);
+                printf(", pop %i, bases %i, factories %i, prod %i (%i), waste %i\n", p->pop, p->missile_bases, p->factories, p->prod_after_maint, p->total_prod, p->waste);
                 if (show_full) {
                     char buf[10];
                     int v;
-                    v = game_planet_get_slider_text(g, p, api, PLANET_SLIDER_SHIP, buf);
+                    v = game_planet_get_slider_text(g, p, PLANET_SLIDER_SHIP, buf, sizeof(buf));
                     printf("  - Build ");
                     if (p->buildship == BUILDSHIP_STARGATE) {
                         printf("%s\n", game_str_sm_stargate);
@@ -225,11 +221,11 @@ void ui_planet_look(const struct game_s *g, int api, uint8_t planet_i, bool show
                         printf("%i %s\n", v, g->srd[api].design[p->buildship].name);
                     }
                     printf("  - Slider %cSHIP %3i  %s\n", p->slider_lock[PLANET_SLIDER_SHIP] ? '*' : ' ', p->slider[PLANET_SLIDER_SHIP], buf);
-                    game_planet_get_slider_text(g, p, api, PLANET_SLIDER_DEF, buf);
+                    game_planet_get_slider_text(g, p, PLANET_SLIDER_DEF, buf, sizeof(buf));
                     printf("  - Slider %c DEF %3i  %s\n", p->slider_lock[PLANET_SLIDER_DEF] ? '*' : ' ', p->slider[PLANET_SLIDER_DEF], buf);
-                    game_planet_get_slider_text(g, p, api, PLANET_SLIDER_IND, buf);
+                    game_planet_get_slider_text(g, p, PLANET_SLIDER_IND, buf, sizeof(buf));
                     printf("  - Slider %c IND %3i  %s\n", p->slider_lock[PLANET_SLIDER_IND] ? '*' : ' ', p->slider[PLANET_SLIDER_IND], buf);
-                    v = game_planet_get_slider_text_eco(g, p, api, true, buf);
+                    v = game_planet_get_slider_text_eco(g, p, true, buf, sizeof(buf));
                     printf("  - Slider %c ECO %3i  ", p->slider_lock[PLANET_SLIDER_ECO] ? '*' : ' ', p->slider[PLANET_SLIDER_ECO]);
                     if (v >= 0) {
                         if (v < 100) {
@@ -239,7 +235,7 @@ void ui_planet_look(const struct game_s *g, int api, uint8_t planet_i, bool show
                         }
                     }
                     printf("%s\n", buf);
-                    game_planet_get_slider_text(g, p, api, PLANET_SLIDER_TECH, buf);
+                    game_planet_get_slider_text(g, p, PLANET_SLIDER_TECH, buf, sizeof(buf));
                     printf("  - Slider %cTECH %3i  %s RP\n", p->slider_lock[PLANET_SLIDER_TECH] ? '*' : ' ', p->slider[PLANET_SLIDER_TECH], buf);
                     if (p->reloc != planet_i) {
                         printf("  - Reloc to %s\n", g->planet[p->reloc].name);
@@ -251,7 +247,7 @@ void ui_planet_look(const struct game_s *g, int api, uint8_t planet_i, bool show
                             printf(" via %s.\n", game_str_sm_stargate);
                         } else {
                             int eta, engine = e->have_engine;
-                            eta = game_calc_eta(g, engine, p->x, p->y, pt->x, pt->y);
+                            eta = game_calc_eta_trans(g, engine, p->x, p->y, pt->x, pt->y);
                             printf(". %s %i %s.\n", game_str_sm_eta, eta, (eta == 1) ? game_str_sm_turn : game_str_sm_turns);
                         }
                     }
@@ -377,6 +373,11 @@ int ui_cmd_planet_build(struct game_s *g, int api, struct input_token_s *param,
         /* TODO handle param */
         return -1;
     }
+    if (p->buildship == BUILDSHIP_STARGATE) {
+        printf("Building %s\n", game_str_sm_stargate);
+    } else {
+        printf("Building %s\n", g->srd[api].design[p->buildship].name);
+    }
     return 0;
 }
 
@@ -393,7 +394,7 @@ int ui_cmd_planet_reloc(struct game_s *g, int api, struct input_token_s *param,
         pti = pfi;
     } else {
         pti = ui_planet_from_param(g, api, param);
-        if ((pti == PLANET_NONE) || (g->planet[pti].owner != api)) {
+        if ((pti == PLANET_NONE) || !game_reloc_dest_ok(g, pti, api)) {
             return -1;
         }
     }
@@ -434,7 +435,7 @@ int ui_cmd_planet_trans(struct game_s *g, int api, struct input_token_s *param,
             return -1;
         }
         if (pt->within_frange[api] != 1) {
-            int mindist = game_get_min_dist(g, api, pfi);
+            int mindist = game_get_min_dist(g, api, pti);
             printf("%s %i %s %i %s\n", game_str_sm_notrange1, mindist, game_str_sm_notrange2, e->fuel_range, game_str_sm_notrange3);
             return -1;
         } else if (BOOLVEC_IS0(pt->explored, api)) {
@@ -442,9 +443,9 @@ int ui_cmd_planet_trans(struct game_s *g, int api, struct input_token_s *param,
             return -1;
         } else if (pt->type < e->have_colony_for) {
             int pos;
-            pos = sprintf(buf, "%s ", game_str_sm_trcontr1);
-            sprintf(&buf[pos], "%s ", game_str_tbl_sm_pltype[pt->type]);
-            util_str_tolower(&buf[pos]);
+            pos = lib_sprintf(buf, sizeof(buf), "%s ", game_str_sm_trcontr1);
+            lib_sprintf(&buf[pos], sizeof(buf) - pos, "%s ", game_str_tbl_sm_pltype[pt->type]);
+            util_str_tolower(&buf[pos], sizeof(buf));
             printf("%s %s\n", buf, game_str_sm_trcontr2);
             return -1;
         } else if (pt->owner == PLAYER_NONE) {
@@ -452,11 +453,11 @@ int ui_cmd_planet_trans(struct game_s *g, int api, struct input_token_s *param,
             return -1;
         } else {
             if (pf->have_stargate && pt->have_stargate && (pf->owner == pt->owner)) {
-                strcpy(buf, game_str_sm_stargate);
+                lib_strcpy(buf, game_str_sm_stargate, sizeof(buf));
             } else {
                 int eta, engine = e->have_engine;
-                eta = game_calc_eta(g, engine, pf->x, pf->y, pt->x, pt->y);
-                sprintf(buf, "%s %i %s", game_str_sm_eta, eta, (eta == 1) ? game_str_sm_turn : game_str_sm_turns);
+                eta = game_calc_eta_trans(g, engine, pf->x, pf->y, pt->x, pt->y);
+                lib_sprintf(buf, sizeof(buf), "%s %i %s", game_str_sm_eta, eta, (eta == 1) ? game_str_sm_turn : game_str_sm_turns);
             }
             puts(buf);
         }
